%% --------------- ABM for household energy demand:------------------------
% Investment and usage decisions for large electric appliances.

% Clustering according to Age and Place of living:
% Cl1: young city
% Cl2: young agglo&country,
% Cl3: middleold city
% Cl4: middleold agglo&country
% Cl5: old city&agglo&country

% Categorization of households according to being large (>2 persons)
% or small, homeowner or renter, and poor (<4500 gross CHF/m) or not poor: 
% Cat1=(large homeowner not poor)
% Cat2=(large homeowner poor)
% Cat3=(large renter not poor)
% Cat4=(large renter poor)
% Cat5=(small homeowner not poor)
% Cat6=(small homeowner poor)
% Cat7=(small renter not poor)
% Cat8=(small renter poor)

clearvars
close all

addpath(genpath(pwd)) % add all subfolders to search path

tic

%% Parameters and Initialization

maxsr = 1; % number of scenario repetitions
maxiter = 9; % number of iterations
ip=1; % for initial setup, set iteration period ip=1
siglevel = .05; % determines which of the estimated effects to consider 

% Initialize structures for cluster, households (agents) and reporting
Input = struct; % "input" at cluster (and category) level (or for NW-specs)
ImpData = struct; % "import data from SHEDS"
hh = struct; % "agents"
report = struct; % "results"
SimReport_sr = struct; % "results of scenario repetitions"

% Descriptive norms, injunctive norms and literacy:
% These are the dimensions for which we checked for significant
% correlations. We use these estimates for the initialization. 
% For the aditionally used clusters and (sometimes) categories we rely on 
% descriptive statistics.
ImpData.numdesc = 5;    % desc = [1,2,3,4,5]
ImpData.numinj = 9;     % inj = [1,1.5,2,...,5]
ImpData.numlit = 12;    % lit = [0,1,2,...,11]
% (Relies on different number of possible values for identification of
% input data; Import_Data needs modifications if to be used with identical 
% number of values for different categorical variables.)

assign_modes.NI = 2; % assign mode for norms & information characteristics
% mode=1: cluster-specific assignment but random at category-level.
% mode=2: cluster- and category-specific assignment

% Import and format SHEDS data (Stata-output):
% Import variables (using ImpData struct), format imported files as 
% matrices in Cl struct and calculate conditional probabilities (necessary
% for assignment of hhs).
[Input, ImpData] = Import_Data(Input,ImpData);

% Chose active modes (for initialization) and set parameters
% Network effects
modes.NW = 'active'; % 'active' or 'inactive'
Input = NW_Parameters(Input);

% Information and trust measure
modes.IT = 'active'; % 'active' or 'inactive'

% Information diffusion
modes.ID = 'active'; % 'active' or 'inactive'

% adjustment of bebavioristic variables (preferred share and effort)
modes.BehavioristicAdjustment = 'active'; % 'active' or 'inactive'

% Electrical appliances
modes.EA = 'active'; % 'active' or 'inactive'
assign_modes.EA = 2; 
% mode=1: cluster-specific assignment but random at category-level.
% mode=2: cluster- and category-specific assignment.
Input = EA_Parameters(Input); % Load parameters for EAs

% Electricity use
modes.EU = 'active'; % 'active' or 'inactive'
Input = EU_Parameters(Input); % Load parameters for EU

 % define if figures for initialization should be produced ('active')
 % or not ('inactive')
Input.figures_initialization = 'inactive';

% Generate hh structure according to imported and set parameters and
% according to active modes; also create NWs for given set of hhs. Finally
% inspect output graphically (histograms) if activated above.
% ! Ensure that vectors of hh characteristics are Nx1 matrices and not 1xN!
% (Necessary for the given coding structure of the ID-Inst function.)
[hh, NW, report] = Initialization(hh,report,Input,ImpData,modes,...
    assign_modes,ip,maxiter);

% Preserve original household and network initialization 
% This is used to run additional model specifications with the same
% population and network structure.
initial.HHStruct = hh; % Later then just reset hh = Initial.HHStruct.
initial.NWStruct = NW;

save([pwd '\results\initialization'])

%% Simulation
tic
tic
addpath(genpath(pwd)) % add all subfolders to search path

close all
clearvars
load initialization.mat

RunName = 'base'; % set run name
maxiter = 9; % reset number of iteration (years)
maxsr = 40; % reset number of sceanrio repetitions

% -------------------------------

for sr = 1:maxsr % repetition of sceanrio run 
    fprintf('Scenario repetition sr = %.0f. ',sr)
    sr_name = sprintf('%s%d','sr',sr);
    sr_names(sr,1) = {sr_name};
    
    SimName = 'base'; % set simulation name   

    % redefine inputs (e.g. price scenario) for different sceanrios:
        Input.ID.max_campaing_effect = 0; % no campaign active
        Input.ID.SNCampaignPeriod = 1; % no campaign active
        Input.ID.SNCampaign = 1; % no campaign active
        Input.ID.TargetLiteracyCampaign = 0; % no target defined
        Input.ID.LitCampaignPeriod = 0; % no campaign active
        Input.EU.price_sceanrio_eu = 0; % constant prices
        Input.EA.price_sceanrio_ea = 0; % constant prices
        Input.ID.Campaign =0; % no campaign active
        Input.ID.TargetClusterSN = 0; % no target cluster defined

    % include Baseline_Definition:
        options = Baseline_Definition(modes,NW,Input,ImpData);

    % overwrite options for scenarios or model set up:    
        options.EA.RandomBuy = 1; % e.g. allow for random buying

    % run simulation
        SimReport.(SimName).(sr_name) = Simulation(hh,report,NW,modes,options,maxiter,SimName);
end
% write results reporting    
    SimReport_sr.(SimName) = reporting_sr(SimReport,maxsr,sr_names,maxiter,SimName);

% -------------------------------

% save results  
    filename=['results_' (RunName)];
    save([pwd '\results\' filename], '-v7.3')

toc


