function hh = EU_AssignHH(hh,Input,ip)
%EU_ASSIGNHH Define electricity usage variables
%%%%%%%%%
% Input: hh, and input, ip
%%%%%%%%%
% Returns: hh structure

 % set variables to assign electricity usage levels
switch ip
    case 1    
        hh.EU.ln{hh.ClNumber,1} = 0;
        hh.EU.level{hh.ClNumber,1} = 0;
end

%% Assign electricity usage variables

% price EU
hh.EU.priceEU = Input.EU.PriceEU;

% EU level and ln
for cl = 1:hh.ClNumber % type loop

    hh.EU.ln{cl,1} = NaN(hh.N(cl),1);
    hh.EU.ChangeEffortByElasticity{cl,1} = NaN(hh.N(cl),1);

    for h = 1:hh.N(cl) % household loop
        % Oct '19: Marginal output from stata at(ea_total=(0(1)8)) over(cl),
        % i.e., recognized as inj; lit significantly interacted with EU.
        % Account for this by calling hh.EA.large.stock!
        hh.EU.ln{cl,1}(h) = max(0,...
            NormalDist(...
                Input.EU.ln.mean(min(9,hh.EA.large.stock{cl,1}(h)),...
                                     (hh.NI.Inj{cl,1}(h)-.5)*2,...
                                      hh.NI.Lit{cl,1}(h)+1,cl),...
                Input.EU.ln.se(min(9,hh.EA.large.stock{cl,1}(h)),...
                                   (hh.NI.Inj{cl,1}(h)-.5)*2,...
                                    hh.NI.Lit{cl,1}(h)+1,cl),...
                1)...
            );
  
    end % close hh loop
    
    hh.EU.level{cl,1} = exp(hh.EU.ln{cl,1}); % EU level 

end

%% Assign effort level and corresponding utilisation of EA (= effort)

switch Input.EU.assign_modes_effort
    case 1 % assign effort on cluster level
        for cl = 1:hh.ClNumber % cl loop
            hh.EU.EffortLevel{cl,1} = NaN(hh.N(cl),1);
            
            for h = 1:hh.N(cl) % household loop

                % Assign Effort levels (1-5 scale) by cl
                Randn = rand;
                for eff = 1:length(Input.EU.EffortLevel.Share(1,:)) 
                    % effort level to reduce EU: 1 (Very unlikely) ... 5 (Very likely)
                    if Randn < Input.EU.EffortLevel.CondProb(cl,eff) ...
                            && isnan(hh.EU.EffortLevel{cl,1}(h))
                        hh.EU.EffortLevel{cl,1}(h,1) = eff;
                    end
                end
            end % end hh loop
        end % end cl loop
        
        % translate effort level into utilisation of EA (= effort):
        % effort level = 5 --> effort = 0.7
        % effort level = 1 --> effort = 1
        for cl = 1:hh.ClNumber % type loop
            for h = 1:hh.N(cl) % household loop     
               hh.EU.Effort{cl,1}(h,1) = min(1,max(Input.EU.min_effort,...
                                                    Input.EU.min_effort...
                                                    + (Input.EU.max_effortlevel...
                                                        - hh.EU.EffortLevel{cl,1}(h,1))...
                                                    *(Input.EU.max_savings_by_effort/4)));                                          
            end
        end
        
        hh.EU.Elasticity_LitEffort = 0; % marginal effect of literacy on effort zero if assignment only on cluster level
        
    case 2 % take into account correlations with literacy and norms when assigning effort
        
        for lit = 1:12
            for inj = 1:9
                for desc = 1:5
                    for cl = 1:hh.ClNumber
                        % translate effort level into utilisation of EA (= effort):
                        % effort level = 5 --> effort = 0.7
                        % effort level = 1 --> effort = 1
                        Input.EU.Effort.predict_scaled(lit,inj,desc,cl) =...
                                                            Input.EU.min_effort...
                                                            + (Input.EU.max_effortlevel...
                                                                - Input.EU.EffortLevel.predict(lit,inj,desc,cl))...
                                                            *(Input.EU.max_savings_by_effort/4);  
                    end
                end
            end
        end
        
        % calculate marginal effect of literacy on effort (elasticity):
        for lit = 2:12
            for inj = 1:9
                for desc = 1:5
                    for cl = 1:hh.ClNumber
                    % marginal effect literacy on effort by cl and lit
                    % level
                    dxdy_LitEffort(lit,inj,desc,cl) = ...
                        (Input.EU.Effort.predict_scaled(lit,inj,desc,cl)...
                            - Input.EU.Effort.predict_scaled(lit-1,inj,desc,cl));
                    end
                end
            end
        end
        hh.EU.Elasticity_LitEffort = mean(nonzeros(dxdy_LitEffort)); % mean marginal effect
         
        % Assign effort to hhs
        for cl = 1:hh.ClNumber % cl loop            
            for h = 1:hh.N(cl) % household loop
                lit = hh.NI.Lit{cl,1}(h) + 1;  % convert to 1 - 12 scale
                inj = (hh.NI.Inj{cl,1}(h) - 0.5) * 2; % convert to 1 - 9 scale
                desc = hh.NI.Desc{cl,1}(h);
                
                hh.EU.EffortLevel{cl,1}(h,1) = max(1,min(Input.EU.max_effortlevel,...
                                                    Input.EU.EffortLevel.predict(lit,inj,desc,cl)));  
                                                
                hh.EU.Effort{cl,1}(h,1) = min(1,max(Input.EU.min_effort,...
                                                    Input.EU.Effort.predict_scaled(lit,inj,desc,cl)));                                
            end  % end hh loop           
        end % end cl loop           
end % end switch

% set initial effort values
for cl = 1:hh.ClNumber % type loop
    hh.EU.InitialEffort{cl,1} = hh.EU.Effort{cl,1};
    hh.EU.InitalEffortLevel{cl,1} = hh.EU.EffortLevel{cl,1}; 
end

%% Derive calibration factor for EU function

% calculate base EU of EEA and NonEEA 
% first on hh level, than derive mean.
% base EU derived from EU level and EA/ EEA stock as well as lower EU of
% EEA
for cl = 1:hh.ClNumber % type loop
        BaseHH = hh.EU.level{cl,1}./ hh.EA.large.stock{cl,1};
        ShareEEA = hh.EA.large.EEA.stock{cl,1}./ hh.EA.large.stock{cl,1};
        BaseHHNONEEA = hh.EU.level{cl,1}...
                        ./(hh.EA.large.stock{cl,1}...
                        .*(hh.EA.large.EEA.stock{cl,1}./ hh.EA.large.stock{cl,1})...
                        .*(1-Input.EU.EEAEnergyReduction)...
                        + (1-(hh.EA.large.EEA.stock{cl,1}...
                        ./ hh.EA.large.stock{cl,1}))...
                        .*hh.EA.large.stock{cl,1}...
                           );
                       
hh.EU.BaseHH{cl,1} = BaseHH; 
hh.EU.ShareEEA{cl,1} = ShareEEA; 
hh.EU.BaseHH_NONEEA{cl,1} = BaseHHNONEEA;
hh.EU.BaseHH_EEA{cl,1} =  BaseHHNONEEA .* (1-Input.EU.EEAEnergyReduction);
hh.EU.sum_BaseHH_NONEEA{cl} = sum(hh.EU.BaseHH_NONEEA{cl});
hh.EU.sum_BaseHH_EEA{cl} = sum(hh.EU.BaseHH_EEA{cl});
end

hh.EU.mean_Base_NONEEA = sum([hh.EU.sum_BaseHH_NONEEA{:}])/sum(hh.N);
%hh.EU.mean_Base_EEA = sum([hh.EU.sum_BaseHH_EEA{:}])/sum(hh.N);
hh.EU.mean_Base_EEA = hh.EU.mean_Base_NONEEA * (1-Input.EU.EEAEnergyReduction);


% derive calibration factor for EU which is fix in iterations
% calibration factor derived based on stockEA, shareEEA or NonEEA, base EU
% of EEA or NonEEA and utilisation from effort. 
% Sofar, familysize not considered
for cl = 1:hh.ClNumber % type loop
        eu_calibrationfactor =... 
                        hh.EU.level{cl,1}...
                        ./((hh.EA.large.stock{cl,1}...
                        .*(hh.EA.large.EEA.stock{cl,1}./ hh.EA.large.stock{cl,1})...
                        .*hh.EU.mean_Base_EEA...
                        .*hh.EU.Effort{cl,1})...
                        + (hh.EA.large.stock{cl,1}...
                        .*(1-(hh.EA.large.EEA.stock{cl,1}./ hh.EA.large.stock{cl,1}))...
                        .*hh.EU.mean_Base_NONEEA...
                        .*hh.EU.Effort{cl,1})...
                           );
                       
    hh.EU.eu_calibrationfactor{cl,1} = eu_calibrationfactor; 

% check if EU level calculated correctly
%    hh.EU.testEU{cl,1} = hh.EA.large.stock{cl,1}.*(hh.EA.large.EEA.stock{cl,1}./ hh.EA.large.stock{cl,1}).*hh.EU.mean_Base_EEA.*hh.EU.Effort{cl,1}.*hh.EU.eu_calibrationfactor{cl,1}...
%                        + hh.EA.large.stock{cl,1}.*(1-(hh.EA.large.EEA.stock{cl,1}./ hh.EA.large.stock{cl,1})).*hh.EU.mean_Base_NONEEA.*hh.EU.Effort{cl,1}.*hh.EU.eu_calibrationfactor{cl,1};
end

% initialize variables for Trend EU
for cl = 1:hh.ClNumber % type loop
    hh.EU.level_previous_iter{cl,1} = hh.EU.level{cl,1};
    hh.EU.levelnew{cl,1} = hh.EU.level{cl,1};
    hh.EU.levelnew_previous_iter{cl,1} = hh.EU.level{cl,1};
end

% initialize change in effort by conversation
for cl = 1:hh.ClNumber % type loop
    hh.EU.Change_Effort_Conv{cl,1}= zeros(hh.N(cl),1);
end

%% define initial rebound effect on effort 
for cl = 1:hh.ClNumber % type loop
    hh.EU.ReboundEffect{cl,1} = zeros(hh.N(cl),1);
    hh.EU.EffortReboundInitial{cl,1} = zeros(hh.N(cl),1);
    
    for h=1:hh.N(cl)
        % calculate size of initial rebound effect dependent on share EEA and min
        % max rebound effect: 
        if hh.EA.large.EEA.share{cl,1}(h) > 0  

            hh.EU.ReboundEffect{cl,1}(h) = (Input.EU.ReboundEffectMax - Input.EU.ReboundEffectMin)...
                                            .* hh.EA.large.EEA.share{cl,1}(h)...
                                            + Input.EU.ReboundEffectMin;
        else
            hh.EU.ReboundEffect{cl,1}(h) = 0;
        end
    end
    
    % calculate new effort after taking into account rebound effect:
    % Effort Rebound = ((baseEEA after taking into account rebound effect
    %                   * StockEEA * Effort) +  baseNonEEA * StockNonEEA * Effort)
    %                   / (StockEEA * baseEEA + StockNonEEA * baseNonEEA)
    hh.EU.EffortReboundInitial{cl,1} = (hh.EU.mean_Base_NONEEA...
                                    .* (1 - Input.EU.EEAEnergyReduction...
                                    .* (1 - hh.EU.ReboundEffect{cl,1}))...
                                    .* hh.EA.large.EEA.stock{cl,1}...
                                    .* hh.EU.Effort{cl,1}...
                                    + hh.EU.mean_Base_NONEEA...
                                    .* (hh.EA.large.stock{cl,1} - hh.EA.large.EEA.stock{cl,1})...
                                    .* hh.EU.Effort{cl,1}...
                                 )...
                                ./(hh.EU.mean_Base_EEA...
                                    .* hh.EA.large.EEA.stock{cl,1}...
                                    + hh.EU.mean_Base_NONEEA...
                                    .* (hh.EA.large.stock{cl,1} - hh.EA.large.EEA.stock{cl,1})...
                                   );  
    % set limits for effort with rebound: between min level and 1                           
    hh.EU.EffortReboundInitial{cl,1} = max(Input.EU.min_effort,min(hh.EU.EffortReboundInitial{cl,1},1));
end

end

