function [hh,ID] = ID_Conversations(hh,NW,modes,options,PM)
% Call from Simulation.m (before decision making).

%% Pick mates
NbyCl = hh.N; % number of agents by cluster
NumCl = numel(NbyCl); % number of clusters
N = sum(NbyCl); % total number of agents

% Determine number of mates for each agent
NMates=max(0,...
    round(NormalDist(options.ID.(PM).NumMates.mean,options.ID.(PM).NumMates.se,N))...
    );

% Create indicator matrix for each encounter for each household
maxNMates = max(NMates);
MatesIndicator = zeros(N,maxNMates);
for i = 1:maxNMates
    MatesIndicator(:,i)=(i<=NMates(:,1)); % "1" indicates conversation
end

% Choose mates as defined by PickMates option
% Output is a N time maxNMates matrix of who meets who, with  any zero
% indicating no encounter at the j=1,...,maxNMates' position.

% output of the following switch-command: "Mates" (matrix of conversations)
switch options.ID.(PM).PickMates % Invalid values ruled out by ID_options.m 
    % (This ensures that "otherwise" is "by some existing network".)
    
    case 'random' % At random
        Mates = MatesIndicator.*(1 + fix(rand(N,maxNMates) .* N)); 
        
    case 'byCl' % By cluster
        for cl=1:NumCl
            low = 1+sum(NbyCl(1:cl-1)); % running index: first hh in cl
            high = sum(NbyCl(1:cl)); % runnding index: last hh in cl
            Mates(low:high,:) = MatesIndicator(low:high,:).*...
                (low + fix(rand(NbyCl(cl),maxNMates) .* NbyCl(cl)));
        end
        
    otherwise % By network defined by options.ID.(PM).PickMates
        IDNW = options.ID.(PM).PickMates; % ID of selected network
        NWbyHH = cell2mat(NW.(IDNW).ID); % Nx2 matrix of network membership
        % For 'strongweak': MUST NOT be sorted while created in CreateNW.m 
        NWMem = NW.(IDNW).Members; % Members (households) by NW IDNW
        maxMem = numel(NWMem(1,:)); % max number of members   
        
        % Allow for strong and weak ties as discussed by e.g. Goldenberg 
        % (2001): 1st NW represent strong, 2nd NW weak ties. The idea is to 
        % have more frequent encounters with and more influence through 
        % strong-ties. Weak ties are met less frequently and their effect 
        % is weaker. Weak-ties encounters are necessary to "spread the 
        % word". This requires a different treatment of 1st and 2nd 
        % networks. For this, MemByHH must not be sorted.
        switch options.ID.(PM).Ties % Invalid values ruled out by ID_options.m
            
            case 'equal' % Treat primary and secondary NWs equally
                % N times (2*maxMem) matrix of HHs belonging to the NWs of 
                % each HH (allows for double entries and contains oneself)
                MembyHH = NaN (N,2*maxMem); % columns 1:maxMem for 1st NW 
                MembyHH(:,1:maxMem) = NWMem(NWbyHH(:,1),1:maxMem); % 1st NW
                MembyHH(~isnan(NWbyHH(:,2)),maxMem+1:2*maxMem) = ...%2nd NW
                    NWMem(NWbyHH(~isnan(NWbyHH(:,2)),2),1:maxMem); 
                
            case 'strongweak' % Treat primary NW as strong tie and 
                % secondary NW as weak tie (see, e.g., Goldenberg 2001).
                % Double-count primary NW.

                % N times (3*maxMem) matrix of HHs belonging to the NWs of 
                % each HH (allows for double entries and contains oneself).
                MembyHH = NaN (N,3*maxMem); % columns 1:2*maxMem for 1st NW 
                MembyHH(:,1:maxMem) = NWMem(NWbyHH(:,1),1:maxMem); % 1st NW
                MembyHH(:,maxMem+1:2*maxMem) = ... % double-counting 1st NW
                    NWMem(NWbyHH(:,1),1:maxMem); 
                MembyHH(~isnan(NWbyHH(:,2)),2*maxMem+1:3*maxMem) = ...
                    NWMem(NWbyHH(~isnan(NWbyHH(:,2)),2),1:maxMem); % 2nd NW
               
        end
        
        % Remove "oneself", i.e. agent 1 removes 1 from list etc.
        for i = 1:N
            MembyHH(i,MembyHH(i,:)==i) = NaN;
        end
        
        MembyHH = sort(MembyHH,2); % NaN at end, use first columns.
        % Count members of NWs for each HH and repeat this value 
        % for each potential member
        NMembyHH(1:N,1) = sum(~isnan(MembyHH),2); % # of NW members
        NMem = repmat(NMembyHH,1,maxNMates); % repeat by column

        % Random draw to choose position for all potential mates.
        % Define position in MembyHH
        MatePos = 1 + fix(rand(N,maxNMates) .* NMem); 

        % Translate position of potential mates to actual HHs
        MatesPotential = NaN(N,maxNMates);
        for i=1:N % Potential mates line-by-line according to MatePos
            MatesPotential(i,1:maxNMates) = ...
                MembyHH(i,MatePos(i,1:maxNMates));
        end

        % Combine with number of encounters
        Mates = MatesIndicator.*MatesPotential; 
        
end

Mates(Mates==0) = NaN;
Mates = sort(Mates,2); % sort in ascending order

ID.Mates = mat2cell(Mates,NbyCl,maxNMates); % save Mates in ID-structure

%% Load attributes (needed later for conversations)
% NI levels (Lit, Inj, Desc)
% Just activate those characteristics that are needed
Inj = cell2mat(hh.NI.Inj); 
Lit = cell2mat(hh.NI.Lit); 
Desc = cell2mat(hh.NI.Desc);
language_region = cell2mat(hh.canton.language_region) + 1;
% 
% % The ID.... form is currently not needed.
% for i=1:N
%     ID.NI.Desc(i,1:NMates(i)) = Desc(Mates(i,1:NMates(i)))';
%     ID.NI.Inj(i,1:NMates(i)) = Inj(Mates(i,1:NMates(i)))';
%     ID.NI.Lit(i,1:NMates(i)) = Lit(Mates(i,1:NMates(i)))';
% end

switch modes.IT
    case 'active'
        from = hh.IT.from;
        for f = 1:numel(from(:,1))
            source = strrep(from(f,:),' ','');
            IT.Info.(source) = cell2mat(hh.IT.Info.(source));
            IT.Trust.(source) = cell2mat(hh.IT.Trust.(source));
        end
end

% EA levels
switch modes.EA
    case 'active'
        largestock = cell2mat(hh.EA.large.stock);  
        EEAshare = cell2mat(hh.EA.large.EEA.share); 
        EEA_PS = cell2mat(hh.EA.large.EEA.PreferredShare);
end

% EU levels 
switch modes.EU
    case 'active'
         eulevel = cell2mat(hh.EU.level);
         eu_PE = cell2mat(hh.EU.Effort);
         
        switch options.ID.Conv_ReferenceDirectionEffortChange % define if eu level or effort used to define direction
            case {'eulevel'}
                % Calculate "comparable" EU levels
                switch modes.EA
                     case 'active'
                         % (No need to consider baseline "default" EU if not
                         % differentiated by hh-types)
                         % Evenutually also consider HH size, or other categorical
                         % information; or something cluster-specific...
                         EUComp = eulevel./...
                             ((1+options.ID.EULSExtraWeight).*largestock...
                             ... %+ smallstock ...
                             );
                     otherwise
                         EUComp = eulevel;
                end  
            case {'effort'}
                EUComp = eu_PE;            
        end
end


%% Conversations sequence
% Create "conversation matrix" and run from conversation to conversation:
% I.e., HH1 --> start talks with e.g. HH100, HH200
% and HH100 --> start talks with e.g. HH1000, HH2000.
% This is what "Mates" matrix tells us; conversations then happen such that
% for the upper example HH100 not only talks with HH1000 and HH2000 but
% also with HH1. As a consequence that actual number of conversations is 
% twice the NumMates.mean number.


CountIndCon = sum(~isnan(Mates),2); % Count individual number of convers.
CountTotal = sum(CountIndCon); % Count total number of conversations

ConversationByHH = NaN(CountTotal,2); % Set up conversation matrix
k=0;
for i=1:N % fill conversation matrix
    lower = k+1;
    upper = CountIndCon(i)+k;
    ConversationByHH(lower:upper,1) = i;
    ConversationByHH(lower:upper,2) = Mates(i,1:CountIndCon(i));
    k=upper;
end

ID.ConversationByHH = ConversationByHH; % Save conversations by household

% Define sequence of conversations (assume random order). This is important
% because conversations change chracteristics of agents.
RandSequence(1:CountTotal,1) = 1:CountTotal; % Set up random sequence
RandSequence(1:CountTotal,2) = rand(CountTotal,1); 
SeqNumber = sortrows(RandSequence,2); % Sequence number of conversations

% Go from conversation to conversation
ConversationSeq = NaN(CountTotal,2);
for i=1:CountTotal % Loop over all conversations
    % Conversation i between Agent1 and Agent2
    Agent1 = ConversationByHH(SeqNumber(i,1),1);
    Agent2 = ConversationByHH(SeqNumber(i,1),2);
    
    % Form conversation sequence (re-ordered ConversationByHH matrix)
    ConversationSeq(i,[1 2]) = [Agent1 Agent2]; 
end
    
ID.ConversationSeq = ConversationSeq; % Save conversation sequence

%% Design of conversations

Topic(1:CountTotal) = 9; % 1:EA,2:EU,3:Info,9:other
EEA_Influencer = zeros(CountTotal,2);
CampaignStrength = zeros(CountTotal,1);
% Direction of influence (default: random assignment, evtl. change below)
Direction(1:CountTotal,1) = 12; % indicates Agent1 influences Agent2
Direction(rand(CountTotal,1)>.5) = 21; % Agent2 --> Agent1
StrongLink = zeros(CountTotal,2);
StrongLinkRelevant = zeros(CountTotal,1);

% Load parameters
EEA_InfDef = options.ID.EEA_InfDefShare; % definition of EEA Influencer 
    % (share of EEA)
TSEAInflMult = options.ID.TSEAInflMult; % TopicScore multiplier if 
    % conversation with influencer (=0 not more likely, =1 double the
    % TS, ...)
TSEACampaignMult= options.ID.TSEACampaignMult;% TopicScore multiplier if campaign
EUCrit = options.ID.EUCritDiff; % Critical difference for comp. EU levels
ITEUCrit = 1; %1 doubles EUCrit (0 EUCrit unchanged, ...)

for i=1:CountTotal % Loop over all conversations
    Agent1 = ConversationSeq(i,1);
    Agent2 = ConversationSeq(i,2);
    
    % 1. Choose "topic" (EA, EU, Mob, ...; let it depend on extra-ordinary 
    % characteristics such as e-car, 100% EEA share)
    TopicScore = options.ID.(PM).TopicScore;
    switch modes.EA
        case 'active'
            % Increase weight of probability of talking about EEA, if one
            % of the two shares is already very high.
            EEA_Influencer(i,[1 2]) = [EEAshare(Agent1)>EEA_InfDef ...
                EEAshare(Agent2)>EEA_InfDef];
            if sum(EEA_Influencer(i,:)) == 1 % only 1 is EEA-influencer
                TopicScore.EA = (1+ TSEAInflMult)...
                    *TopicScore.EA; % more likely to talk about EA
            end % If both are influencer, there is no room to influence
    end
    
    % Campaign adresses diffusion of information:
    % Increase weight of probability of talking about EEA,
    % dependent on Desc/ Inj/ Lit level of agent. Max increase if both agents 
    % have highest Desc/ Inj/ Lit  level
    switch options.ID.Campaign
        case 'desc'
            CampaignStrength(i) = (Desc(Agent1) + Desc(Agent2))/(max(Desc)*2);
            TopicScore.EA = (1+ TSEACampaignMult)*CampaignStrength(i)...
                *TopicScore.EA; % more likely to talk about EA 
        case 'inj'
            CampaignStrength(i) = (Inj(Agent1) + Inj(Agent2))/(max(Inj)*2);
            TopicScore.EA = (1+ TSEACampaignMult)*CampaignStrength(i)...
                *TopicScore.EA; % more likely to talk about EA 
        case 'lit'
            CampaignStrength(i) = (Lit(Agent1) + Lit(Agent2))/(max(Lit)*2);
            TopicScore.Info = (1+ TSEACampaignMult)*CampaignStrength(i)...
                *TopicScore.Info; % more likely to talk about EA             
    end
    
    TotalWeight = sum(cell2mat(struct2cell(TopicScore))); % update weight
    Randn = rand;
    if Randn < TopicScore.EA/TotalWeight
        Topic(i) = 1; % 1: EA (SN channel)
    elseif Randn < (TopicScore.EA+TopicScore.EU)/TotalWeight
        Topic(i) = 2; % 2: EU (SN channel)
    elseif Randn <(TopicScore.EA+TopicScore.EU+TopicScore.Info)/TotalWeight
        Topic(i) = 3; % 3: Learning (Information channel)
    end    
    
    % 2. Choose direction of influence (compare values/factors) 
    % change random decision eventually according to topic, influencer, NI:
    
    % a) Look at IT (This allows to stay uninformed if Trust is low)
    DirectionIT=0; %Indicator variable if direction changed due to IT.
    switch modes.IT
        case 'active'
            switch options.ID.(PM).PickMates 
                case {'random','bycl'}
                    % Calculate avg trust in people: if one
                    % agent has a substantially higher 
                    % value, this agent is influenced by 
                    % the other agent.
                    % The possible values range from 2 to
                    % 10. If the difference exceeds 2, the
                    % direction is determined by trust
                    % levels.
                    Diff = IT.Trust.fam(Agent1) ...
                        + IT.Trust.neighbor(Agent1) ...
                        - IT.Trust.fam(Agent2) ...
                        - IT.Trust.neighbor(Agent2);
                    if Diff > 2 % Trust A1 subst. larger
                        Direction(i) = 21; % A1 influenced by A2
                        DirectionIT = 1;
                    elseif Diff < -2 % Trust A2 subst. larger
                        Direction(i) = 12; % A2 influenced by A1
                        DirectionIT = 1;
                    end    

                case 'Neighborhood'
                    Diff = IT.Trust.neighbor(Agent1) ...
                        - IT.Trust.neighbor(Agent2);
                    if Diff > 1 % Trust A1 subst. larger
                        Direction(i) = 21;
                        DirectionIT = 1;
                    elseif Diff < -1
                        Direction(i) = 12;
                        DirectionIT = 1;
                    end    
                case {'Family','Friends'}
                    Diff = IT.Trust.fam(Agent1) ...
                        - IT.Trust.fam(Agent2);
                    if Diff > 1 % Trust A1 subst. larger
                        Direction(i) = 21;
                        DirectionIT = 1;
                    elseif Diff < -1
                        Direction(i) = 12;
                        DirectionIT = 1;
                    end                                    

            end
    end
    
    % b) Look at topic
    switch Topic(i)
        case 1 % EA
            switch options.ID.Conv_Direction_ea
                case 1
                    % Overwrite random direction if injunctive norm pressure 
                    % different: Agent with higher pressure adjusts
                    DiffInj = Inj(Agent1) - Inj(Agent2);
                    switch DirectionIT
                        case 0 % Choice of direction still "free"
                            if DiffInj>1 
                                Direction(i) = 21; 
                            elseif DiffInj<-1
                                Direction(i) = 12;
                            end
                        case 1 % Direction already changed due to differences in IT
                            if DiffInj>2 % require larger difference in inj-level 
                                Direction(i) = 21; 
                            elseif DiffInj<-2
                                Direction(i) = 12;
                            end
                    end
            end

            % Influencer overwrites Trust (?, if not, move to switch above) 
            switch sum(EEA_Influencer(i,:))
                case 1 % only one of the two is influencer: direction clear
                    if EEA_Influencer(i,1) == 1 % Agent 1 is influencer
                        Direction(i) = 12;
                    else % Agent 2 is influencer
                        Direction(i) = 21;
                    end
                otherwise % none is an influencer (or modes.EA not active)
                    % or both are influencers: change nothing
            end

            
        case 2 % EU
            switch modes.EU
                case 'active' 
                    switch options.ID.Conv_Direction_eu_effort % use EU or effort to define direction (=0) or use injunctive norm pressure (=1)
                        
                        case 0 % EU or effort to define direction
                            % stick with previous direction if both have 
                            % comparable electricity consumption
                            switch DirectionIT
                                case 0 % use EUCrit if DirectionIT not active
                                    if EUComp(Agent1)<=(1-EUCrit)*EUComp(Agent2)
                                        Direction(i) = 12; % if 1 consumes less
                                    elseif EUComp(Agent2)<=(1-EUCrit)*EUComp(Agent1)
                                        Direction(i) = 21; % if 2 consumes less
                                    end
                                case 1 % required EUCrit higher if DirectionIT=1
                                    if EUComp(Agent1)<=(...
                                            1-EUCrit*(1+ITEUCrit)...
                                            )...
                                            *EUComp(Agent2)
                                        Direction(i) = 12; % if 1 consumes less
                                    elseif EUComp(Agent2)<=(...
                                            1-EUCrit*(1+ITEUCrit)...
                                            )...
                                            *EUComp(Agent1)
                                        Direction(i) = 21; % if 2 consumes less
                                    end
                            end
                        
                        case 1 % injunctive norm pressure to define direction
                            % Overwrite random direction if injunctive norm pressure 
                            % different: Agent with higher pressure adjusts
                            DiffInj = Inj(Agent1) - Inj(Agent2);
                            switch DirectionIT
                                case 0 % Choice of direction still "free"
                                    if DiffInj>1 
                                        Direction(i) = 21; 
                                    elseif DiffInj<-1
                                        Direction(i) = 12;
                                    end
                                case 1 % Direction already changed due to differences in IT
                                    if DiffInj>2 % require larger difference in inj-level 
                                        Direction(i) = 21; 
                                    elseif DiffInj<-2
                                        Direction(i) = 12;
                                    end
                            end                                                         
                    end
            end
        case 3 % Info
            % eventually add Info-specific cause for a change of direction. 
            
            switch options.ID.Conv_Direction_Lit % Use Lit level to define direction for learning (=1)
                case 1 % Use literacy level to define direction
                    % Overwrite random direction if literacy level 
                    % different: Agent with lower literacy adjusts
                    DiffLit = Lit(Agent1) - Lit(Agent2);
                    switch DirectionIT
                        case 0 % Choice of direction still "free"
                            if DiffLit>1 
                                Direction(i) = 12; 
                            elseif DiffLit<-1
                                Direction(i) = 21;
                            end
                        case 1 % Direction already changed due to differences in IT
                            if DiffLit>2 % require larger difference in lit-level 
                                Direction(i) = 12; 
                            elseif DiffLit<-2
                                Direction(i) = 21;
                            end
                    end
            end
    end
    
    
    % 3. Determine influence (change hh-struct and account for StrongLink)
    % If allocation of conversations by NW and "strongweak" option active,
    % then create stronger link for those agents that meet from primary NW.
    if options.ID.(PM).byNW == 1
        switch options.ID.(PM).Ties 
            case 'strongweak' % Treat primary NW link as strong tie 
                PrimNW=NWbyHH([Agent1 Agent2],1); % Define primary networks
                % Check if primary network is the link to the other Agent
                SL1 = sum(PrimNW(1)==NWbyHH(Agent2,:)); 
                SL2 = sum(PrimNW(2)==NWbyHH(Agent1,:));
                StrongLink(i,[1 2]) = [SL1 SL2];
                
                % Check if strong link is relevant (1 if relevant, 0 else)
                StrongLinkRelevant(i) = ((Direction(i) == 12 && SL1==1)...
                    || (Direction(i) == 21 && SL2==1));
        end
    end
end

ID.Topic = Topic;
ID.EEA_Influencer = EEA_Influencer;
ID.Direction = Direction;
ID.StrongLink = StrongLink;
ID.StrongLinkRelevant = StrongLinkRelevant;


%% Consequences of conversations: Prepare changes

ChangeEEA = zeros(N,1);
ChangeEU = zeros(N,1);
LimitedByInfo = zeros(N,1);
change_eu_PE = zeros(N,1); % effort
LimitedByInfo_PE = zeros(N,1); % LBI for effort
ChangeInfo = zeros(N,1);

% Define weights for adjustment of preferred EEA share
WeightEEA = options.ID.WeightEEA;
ShifterEEA = options.ID.ShifterEEA;
% Higher level if StrongLinkRelevant == 1
WeightEEA_SLR = WeightEEA + ShifterEEA.*StrongLinkRelevant(:);
WeightEEA_SLR(WeightEEA_SLR>1) = 1; % weight cannot exceed 1

% Define weights for adjustment of preferred EU share
WeightEU = options.ID.WeightEU;
ShifterEU = options.ID.ShifterEU;
% Higher level if StrongLinkRelevant == 1 
WeightEU_SLR = WeightEU + ShifterEU.*StrongLinkRelevant(:);
WeightEU_SLR(WeightEU_SLR>1) = 1; % weight cannot exceed 1

% Effect of limited by Info 
LBIEU = options.ID.LBIEU; % EU
LBIEEA = options.ID.LBIEEA; % EEA

% Define weights for adjustment of preference by Info
WeightInfo = options.ID.WeightInfo;
ShifterInfo = options.ID.ShifterInfo;
% Higher level if StrongLinkRelevant == 1 
WeightInfo_SLR = WeightInfo + ShifterInfo.*StrongLinkRelevant(:);
WeightInfo_SLR(WeightInfo_SLR>1) = 1; % weight cannot exceed 1

for i=1:CountTotal % Loop over all conversations
    Agent1 = ConversationSeq(i,1);
    Agent2 = ConversationSeq(i,2);
    
    switch Topic(i)
        case 1 % 'EA' (SN Channel)
            % Compare Preferred EEA levels and adjust imperfectly according 
            % to direction & weight and stronger for stronglinkrelevant.
            switch modes.EA
                case 'active' % if modes.EA inactive, do nothing
                    switch Direction(i) 
                        case 12 
                            % Change = old change + new level - old level
                            ChangeEEA(Agent2) = ChangeEEA(Agent2) ...
                                + WeightEEA_SLR(i,language_region(Agent2)) ... use updated values
                                    *(EEA_PS(Agent1)+ChangeEEA(Agent1)) ...
                                + (1-WeightEEA_SLR(i,language_region(Agent2))) ...
                                    *(EEA_PS(Agent2)+ChangeEEA(Agent2)) ...
                                - EEA_PS(Agent2);
                        case 21
                            ChangeEEA(Agent1) = ChangeEEA(Agent1) ...
                                + WeightEEA_SLR(i,language_region(Agent1)) ...
                                    *(EEA_PS(Agent2)+ChangeEEA(Agent2)) ...
                                + (1-WeightEEA_SLR(i,language_region(Agent1))) ...
                                    *(EEA_PS(Agent1)+ChangeEEA(Agent1)) ...
                                - EEA_PS(Agent1);
                    end
            end
                                
        case 2 % 'EU' (SN channel)
            % Compare EU and adjust, accounting for HH characteristica
            switch modes.EU
                case 'active' % if moded.EU inactive, do nothing
                    switch Direction(i)
                        case 12
                            ChangeEU(Agent2) = ChangeEU(Agent2) ...
                                + WeightEU_SLR(i,language_region(Agent2)) ...
                                    *(eulevel(Agent1)+ChangeEU(Agent1)) ...
                                + (1-WeightEU_SLR(i,language_region(Agent2))) ...
                                    *(eulevel(Agent2)+ChangeEU(Agent2)) ...
                                - eulevel(Agent2);

                            change_eu_PE(Agent2) = change_eu_PE(Agent2)...
                                + (eu_PE(Agent1) + change_eu_PE(Agent1)) * WeightEU_SLR(i,language_region(Agent2))...
                                + (eu_PE(Agent2) + change_eu_PE(Agent2)) * (1-WeightEU_SLR(i,language_region(Agent2)))...
                                - eu_PE(Agent2); 
                        case 21
                            ChangeEU(Agent1) = ChangeEU(Agent1) ...
                                + WeightEU_SLR(i,language_region(Agent1)) ...
                                    *(eulevel(Agent2)+ChangeEU(Agent2)) ...
                                + (1-WeightEU_SLR(i,language_region(Agent1))) ...
                                    *(eulevel(Agent1)+ChangeEU(Agent1)) ...
                                - eulevel(Agent1);

                            change_eu_PE(Agent1) = change_eu_PE(Agent1)...
                                + (eu_PE(Agent2) + change_eu_PE(Agent2)) * WeightEU_SLR(i,language_region(Agent1))...
                                + (eu_PE(Agent1) + change_eu_PE(Agent1)) * (1-WeightEU_SLR(i,language_region(Agent1)))...
                                - eu_PE(Agent1);  
                    end
            end
            
        case 3 % 'Learning' (Information channel)
            switch Direction(i) 
                case 12 
                    % Change = old change + new level - old level
                    ChangeInfo(Agent2) = ChangeInfo(Agent2) ...
                        + WeightInfo_SLR(i,language_region(Agent2)) ... use updated values
                            *(Lit(Agent1)+ChangeInfo(Agent1)) ...
                        + (1-WeightInfo_SLR(i,language_region(Agent2))) ...
                            *(Lit(Agent2)+ChangeInfo(Agent2)) ...
                        - Lit(Agent2);
                case 21
                    ChangeInfo(Agent1) = ChangeInfo(Agent1) ...
                        + WeightInfo_SLR(i,language_region(Agent1)) ... use updated values
                            *(Lit(Agent2)+ChangeInfo(Agent2)) ...
                        + (1-WeightInfo_SLR(i,language_region(Agent1))) ...
                            *(Lit(Agent1)+ChangeInfo(Agent1)) ...
                        - Lit(Agent1);
            end
            
        %otherwise
            % Probably nothing changes (or NI, but this rather by chance?)
    end
    
    % Decrease overall change again for agents that have not picked up info
    % from given network before (if options.ID.(PM).PickMates is by NW)
    switch modes.IT
        case 'active'
            switch options.ID.(PM).PickMates
                case 'Neighborhood'
                    % if influenced agent has not picked up information
                    % from neighbor before, weaken the effect again
                    
                    if Direction(i) == 12 && IT.Info.neighbor(Agent2) == 0
                        ChangeEU(Agent2) = ChangeEU(Agent2)*(1-LBIEU);
                        ChangeEEA(Agent2) = ChangeEEA(Agent2)*(1-LBIEEA);
                        LimitedByInfo(Agent2) = 1;
                        change_eu_PE(Agent2) = change_eu_PE(Agent2)*(1-LBIEU);
                        LimitedByInfo_PE(Agent2) = 1;
                    elseif Direction(i) == 21 && ...
                            IT.Info.neighbor(Agent1) == 0
                        ChangeEU(Agent1) = ChangeEU(Agent1)*(1-LBIEU);
                        ChangeEEA(Agent1) = ChangeEEA(Agent1)*(1-LBIEEA);
                        LimitedByInfo(Agent1) = 1;
                        change_eu_PE(Agent1) = change_eu_PE(Agent1)*(1-LBIEU);
                        LimitedByInfo_PE(Agent1) = 1;
                    end
                case {'Family','Friends' }
                    if Direction(i) == 12 && IT.Info.fam(Agent2) == 0
                        ChangeEU(Agent2) = ChangeEU(Agent2)*(1-LBIEU);
                        ChangeEEA(Agent2) = ChangeEEA(Agent2)*(1-LBIEEA);
                        LimitedByInfo(Agent2) = 1;
                        change_eu_PE(Agent2) = change_eu_PE(Agent2)*(1-LBIEU);
                        LimitedByInfo_PE(Agent2) = 1;

                    elseif Direction(i) == 21 && IT.Info.fam(Agent1) == 0
                        ChangeEU(Agent1) = ChangeEU(Agent1)*(1-LBIEU);
                        ChangeEEA(Agent1) = ChangeEEA(Agent1)*(1-LBIEEA);
                        LimitedByInfo(Agent1) = 1;
                        change_eu_PE(Agent1) = change_eu_PE(Agent1)*(1-LBIEU);
                        LimitedByInfo_PE(Agent1) = 1;
                    end
            end
    end
                
end


% Limit EEA_PS between 0 and 1
ChangeEEA = min((1-EEA_PS),max(-EEA_PS,ChangeEEA));
ID.ChangeEEA = mat2cell(ChangeEEA,NbyCl,1);
% Limit EU_PE between min_EU_PE (=EUFixshare) and 1
change_eu_PE = min((1-eu_PE),max(-(eu_PE-options.EU.min_effort),change_eu_PE));
ID.change_eu_PE = mat2cell(change_eu_PE,NbyCl,1);

ChangeIndicator(:,[1 2 3]) = [~change_eu_PE==0 ~ChangeEEA==0 ~ChangeInfo==0];
ID.ChangeIndicator = mat2cell(ChangeIndicator,NbyCl,...
    numel(ChangeIndicator(1,:)));

SumChangeInd = sum(ChangeIndicator,2);
ID.SumChangeInd = mat2cell(SumChangeInd,NbyCl,1);

ID.LimitedByInfo = mat2cell(LimitedByInfo,NbyCl,1);
ID.LimitedByInfo_PE = mat2cell(LimitedByInfo_PE,NbyCl,1);



% Update changed hh-characteristics
try 
    OldLearning = cell2mat(hh.NI.Learning);
catch
    OldLearning = zeros('like',ChangeInfo);
end
hh.NI.Learning = mat2cell(OldLearning + ChangeInfo,NbyCl);

switch modes.EA
    case 'active' 
        try 
            OldChangeEEA = cell2mat(hh.EA.large.EEA.Change_EEA_PS_Conv);
        catch
            OldChangeEEA = zeros('like',ChangeEEA);
        end
        hh.EA.large.EEA.Change_EEA_PS_Conv = ...
            mat2cell(OldChangeEEA + ChangeEEA,NbyCl);

end
switch modes.EU
    case 'active' 
        try 
            OldChangeEUPE = cell2mat(hh.EU.Change_Effort_Conv);
        catch
            OldChangeEUPE = zeros('like',change_eu_PE);
        end
        hh.EU.Change_Effort_Conv = ...
            mat2cell(OldChangeEUPE + change_eu_PE,NbyCl);
end

end
