function [hh,ID] = ID_Institutions(hh,NW,ID,report,modes,options,ip)
%ID_INSTITUTIONS Defines ID by institutions and calls ID_SN_channel
%%%%%%%%%
% Input: [These structs might be used for definition of ReferenceVar]
%   - structures hh, NW, ID, [report], [modes], [options]. 
%   - ip
%%%%%%%%%
% Returns/updates: hh structure and ID structure

% Call from Simulation.m (before decision making). 
% SN channels work only from second period onwards, i.e., ip>=2. And even 
% only later, if they rely, e.g., on buy measures from previous period.

% -----------------------Comments & ToDos
% - Institutions as central agents: potentiall include many institutions
% - "Shocks" to the system: Institution starts information campaign, plays
% around with strategy how to approach agents.
% - What can the institution influence and how strong?
%   x Change household characteristics (e.g. NI: improve Lit)
%   x Change household behavior (e.g. effects of NI on EU/EA: sign. corr. 
%   between desc and EU through family NW for cl 5)
%   x Change household preferences (e.g. PS_LEA)
%   x Change EU directly (not very interesting)
%   x Create knowledge and/or awareness (e.g. about avg. EU by cl and 
%   activate/introduce desc norm channel)
%   x Create incentives: soft or hard (e.g. for energy-saving
%   behavior/investment in form of rewards) UNCLEAR, HOW COULD THIS WORK??
% - Allow for multiple strategies
% - Track patterns and trickle-down of consequences of institutional ID.Inst 
% - Link to data/literature
% -----------------------

% Norms and literacy both affect the agent's behavior, but in quite 
% different ways: Norms push or pull the behavior to some exogenous level,
% whereas the degree of literacy determines how much an agent's decision is
% aligned with the agent's preferences. When modeling what institutions can
% do, this means that they might be able to directly change literacy levels
% but that changing perceived norm-pressure is much harder. With regard to
% norms, instead, institutions rather try to set or change the awareness of 
% a social norm as well as the according point of reference. 
% In short: Institutions plausibly affect lit levels but not social norm
% levels. They can, however, affect what the reference point for a given
% norm-pressure should be. I.e., the SN channel below is only "controlled"
% indirectly (through changing the reference point); in contrast, the 
% Lit-channel{1} is controlled more directly.

%% Activate SN channels (indirect changes in preferences and behavior)

% Descriptive SN
% Those who trust the SFOE are made aware of some average (e.g., similar,
% cluster-specific, "pioneers") behavioral variable (such as BuyEEAShare). 
% from the previous period. Depending on the descriptive SN level, each 
% agent decID.Instes whether to update its PS and if so by how much.

% Injuctive SN
% The SFOE might also be pushing for the agent's injunctive norm pressure:
% E.g., by announcing what some policy (energy strategy) expects or 
% requires as a change.

% The mechanics of both channels are the same, but take the different
% levels of the respective norm into account, plus the definition of the 
% reference point is different. desc: observed behavior, inj: value-driven 
% expected (i.e., probably not observed) behavior. 
% --> Need to write one function how institutions change preferences and 
% behavior through SN!

% Interplay of both norms? Most simple case independent - they just add up.

% Possible variables for EA
% - ChangeStock = -1, which might be interpreted as a link to sufficiency
% - PreferredEEAShare
% - RenewEvery
% The first two as desc, RenewEvery as inj?
% For EU: desc already used (sign. correlation for cl5), inj not plausible
% (EU not visible enough).


% Descriptive and injunct. norm (mimic o-power's household energy reviews!)

for j = 1:numel(options.ID.Inst.Channels(:,1))
    Name = strrep(options.ID.Inst.Channels(j,:),' ','');
    if ismember(ip,options.ID.Inst.(Name).CampaignPeriod)
        [hh,ID.Inst.(Name)] = ID_SN_channel(hh,NW,options.ID.Inst.(Name));
    else
        ID.Inst.(Name).target = NaN(sum(hh.N),1);
        ID.Inst.(Name).FullStrength = NaN(sum(hh.N),1);
        ID.Inst.(Name).PartlyFS = NaN(sum(hh.N),1);
        ID.Inst.(Name).Strong = NaN(sum(hh.N),1);
        ID.Inst.(Name).PartlySt = NaN(sum(hh.N),1);
        ID.Inst.(Name).NotWeak = NaN(sum(hh.N),1);
        ID.Inst.(Name).EffectStrength = NaN(sum(hh.N),1);
        ID.Inst.(Name).ChannelStrength = NaN(sum(hh.N),1);
        ID.Inst.(Name).AggStrength = NaN(sum(hh.N),1);
        ID.Inst.(Name).change = NaN(sum(hh.N),1);
        ID.Inst.(Name).update = NaN(sum(hh.N),1);
    end
end

%% Activate literacy channel (direct change in characteristics (i.e. literacy level))

% literacy campaign e.g. by SFOE:
% objective is to increase literacy level

% set change variable to zero if lit campaign inactive
for cl=1:hh.ClNumber % cluster loop   
    hh.NI.change_lit{cl,1} = zeros(hh.N(cl),1);   
end % end cluster loop
        
% literacy only adjusted if ID Literacy activated (=1)
switch options.ID.Literacy
        case 1 % lit campaign active
            % literacy only adjusted in campaign periods
            if ismember(ip,options.ID.LitCampaignPeriod)
                        % Trust in sender and took info from
                        trust_sender = cell2mat(hh.IT.Trust.(options.ID.campaignsender_lit));
                        info_from = cell2mat(hh.IT.Info.(options.ID.campaignsender_lit));   
                        
                        % total number of HHs
                        N = sum(hh.N);
                        
                        % clusters
                        cluster = cell2mat(hh.cl);
                        
                        % max effect of lit campaign
                        MaxEfLit = options.ID.MaxEffectLitCampaign;

                        % define strength of Lit Campaign based on trust in sender
                        FullStrengthLit  = (trust_sender==max(trust_sender));
                        PartlyFSLit = (trust_sender>0.75*max(trust_sender)) - FullStrengthLit;
                        StrongLit = (trust_sender>0.5*max(trust_sender)) - FullStrengthLit - PartlyFSLit;
                        PartlyStLit = (trust_sender>0.25*max(trust_sender)) - FullStrengthLit - PartlyFSLit - StrongLit;
                        NotWeakLit = FullStrengthLit + PartlyFSLit + StrongLit+ PartlyStLit;
                        if max(NotWeakLit)>1
                            error('max(NotWeakLit)>1: Check indicator variables for EffectStrength.')
                        end
                        WeakLit = 1- NotWeakLit;

                        % Aggregate Strength, only if HH takes info from sender
                        AggEffectLitCampaign = (MaxEfLit(1)*FullStrengthLit...
                                                 + MaxEfLit(2)*PartlyFSLit...
                                                 + MaxEfLit(3)*StrongLit...
                                                 + MaxEfLit(4)*PartlyStLit...
                                                 + MaxEfLit(5)*WeakLit...
                                                ).*info_from;
                        
                        % Literacy level and reference literacy level
                        LitLevel = cell2mat(hh.NI.Lit);                        
                        switch options.ID.ReferenceLitLevel
                            case 'no_ref' % if no reference 
                                NWMem = 0;
                                ReferenceLitLevel(1:hh.N,1) = 0;                                
                            case 'NW' % if reference from network
                                NWMem =...
                                    cell2mat(NW.(options.ID.ReferenceLitLevel).ID);
                                ReferenceLitLevel(1:N,1) =...
                                    NW.(options.ID.ReferenceLitLevel).NI.Lit(NWMem(1:N,1)); 
                            otherwise
                                NWMem = 0;
                                ReferenceLitLevel(1:N,1) = mean(cell2mat(hh.NI.Lit));
                                
                                
                        end
                                               
                        % change in literacy level due to campaign (based on reference lit level from NW):
                        % Unrestricted change
                        switch options.ID.ReferenceLitLevel
                            case 'no_ref' % if no reference (percentage change of current lit level)
                                urchange_lit = max(options.ID.LowerLimitLitChange,...
                                                    min(options.ID.UpperLimitLitChange,...
                                                        AggEffectLitCampaign...
                                                        .* (LitLevel))); 
                            otherwise % if reference from network
                                urchange_lit = max(options.ID.LowerLimitLitChange,...
                                            min(options.ID.UpperLimitLitChange,...
                                                AggEffectLitCampaign...
                                                .* (ReferenceLitLevel...
                                                        - LitLevel))); 
                        end % end switch options.ID.ReferenceLitLevel
                                
                        % Restrict change
                        switch options.ID.RelationLitChange
                            case 'eq' % two-sided adjustment
                                change_lit = urchange_lit;
                            case 'geq' % only values "too low" change
                                change_lit = max(0,urchange_lit);
                            case 'leq' % only values "too high" change
                                change_lit = min(0,urchange_lit);
                        end 
                        
                        % set change back to zero if campaign only for specifc cluster 
                        switch options.ID.ClusterTailoredLitCampaign
                            case 0
                                
                            case 1
                                change_lit(cluster==2) =  0;
                                change_lit(cluster==3) =  0;
                                change_lit(cluster==4) =  0;
                                change_lit(cluster==5) =  0;
                            case 2
                                change_lit(cluster==1) =  0;
                                change_lit(cluster==3) =  0;
                                change_lit(cluster==4) =  0;
                                change_lit(cluster==5) =  0;
                                
                           case 3
                                change_lit(cluster==1) =  0;
                                change_lit(cluster==2) =  0;
                                change_lit(cluster==4) =  0;
                                change_lit(cluster==5) =  0;
                           case 4
                                change_lit(cluster==1) =  0;
                                change_lit(cluster==2) =  0;
                                change_lit(cluster==3) =  0;
                                change_lit(cluster==5) =  0;
                           case 5
                                change_lit(cluster==1) =  0;
                                change_lit(cluster==2) =  0;
                                change_lit(cluster==3) =  0;
                                change_lit(cluster==4) =  0;
                           case 6 % campaign for cluster 1 & cluster 2
                               change_lit(cluster==3) =  0;
                               change_lit(cluster==4) =  0;
                               change_lit(cluster==5) =  0;
                           case 7 % campaign for cluster 3 & cluster 4
                               change_lit(cluster==1) =  0;
                               change_lit(cluster==2) =  0;
                               change_lit(cluster==5) =  0;
                        end
                            
                            
                            
                        % change in lit by cluster
                        hh.NI.change_lit = mat2cell(change_lit,hh.N,1);                                                                                 
            end % end if condition ip            
end % end switch options.ID.Literacy


end
