function [hh,IDInst] = ID_SN_channel(hh,NW,IDsetup)
%ID_SN_CHANNEL determines how institutions change hh characteristics using
% a social norm channel.
%%%%%%%%%
% Input: 
%   - structures hh,NW and IDsetup. 
%   IDsetup with the following fields:
%   - ChangeVar: Char vector of path to influenced variable in hh-struct
%   - ReferenceVar: Nx1 vector as reference point for comparison
%   - ITverb: inform or trust relevant
%   - ITnoun: institution who informs/is being trusted (SFOE/utility)
%   - Channel: social norm channel (desc or inj)
%   - Relation: one- or two-sided adjustments (geq,eq,leq)
%   - MaxEffect: 5x1 scaling vector for effect (0: no effect for all, 1: 
%       full effect) for FullStrength, PartlyFS, Strong, PartlySt, Weak.
%%%%%%%%%
% Returns/updates: hh structure and IDInst structure for reporting

ChangeV = IDsetup.ChangeVar;
ReferenceD = IDsetup.ReferenceDef;
ITv = IDsetup.ITverb;
ITn = IDsetup.ITnoun;
Chan = IDsetup.Channel;
Rel = IDsetup.Relation;
MaxEf = IDsetup.MaxEffect;
Ceil = IDsetup.Ceil;
Floor = IDsetup.Floor;
RefD = IDsetup.RefD;
RefVar = IDsetup.ReferenceVar;
TargetClSN= IDsetup.TargetClusterSN;

N = sum(hh.N);
NumCl = numel(hh.N);
clusters = cell2mat(hh.cl);

%% Generate reference variable from numeric input or from dynamic path
if RefD == 0 % use NW variable as reference
    if isnumeric(ReferenceD)
        switch numel(ReferenceD)
            case 1
                ReferenceVar(1:N,1) = ReferenceD;
            case NumCl % referency by cluster
                from = 0;
                for clus = 1:NumCl
                    till = from +hh.N(clus);
                    ReferenceVar(from:till) = ReferenceD(clus);
                    from = till+1;
                end
            case N
                ReferenceVar = ReferenceD;
            otherwise
                error('numel(ReferenceDef) = %.0f is invalid length of ReferenceDef variable. Must be constant, cluster-specific or hh-specific.',numel(ReferenceD))
        end
    elseif ischar(ReferenceD)
        NWName = strrep(ReferenceD(1,:),' ',''); % First line contains NW Name
        if ~isfield(NW,(NWName))
            error('%s is an invalid 1st line of ReferenceDef as character vector; it must contain valid NW name.',NWName);
        end
        NWMem = cell2mat(NW.(NWName).ID); % NW membership by hh
        switch numel(ReferenceD(:,1)) % depth = numel-1
            % subpath into NW.(NWName) reporting struct
            case 2 % depth = 1
                sub1 = strrep(ReferenceD(2,:),' ',''); 
                path = NW.(NWName).(sub1);
            case 3 % depth = 2
                sub1 = strrep(ReferenceD(2,:),' ',''); 
                sub2 = strrep(ReferenceD(3,:),' ',''); 
                path = NW.(NWName).(sub1).(sub2);
            case 4 % depth = 3
                sub1 = strrep(ReferenceD(2,:),' ',''); 
                sub2 = strrep(ReferenceD(3,:),' ',''); 
                sub3 = strrep(ReferenceD(4,:),' ',''); 
                path = NW.(NWName).(sub1).(sub2).(sub3);
            case 5 % depth = 4
                sub1 = strrep(ReferenceD(2,:),' ',''); 
                sub2 = strrep(ReferenceD(3,:),' ',''); 
                sub3 = strrep(ReferenceD(4,:),' ',''); 
                sub4 = strrep(ReferenceD(5,:),' ',''); 
                path = NW.(NWName).(sub1).(sub2).(sub3).(sub4);
            otherwise
                error('RererenceDef must containt NWName in first line and path to NW reporting struct in lines 2 [3[4[5]]].')
        end

        % Build ReferenceVar according to NWName and path
        ReferenceVar(1:N,1) = path(NWMem(1:N,1)); 

    else
        error('ReferenceDef in invalid format. Must be numeric (length 1, Cl.number or N) or character vector (with path and NW-link).')
    end
    
else % use no NW variable as reference, but other
    
    switch numel(RefVar(:,1)) % depth = numel-1
        case 5 % depth = 4
                sub1 = strrep(RefVar(2,:),' ',''); 
                sub2 = strrep(RefVar(3,:),' ',''); 
                sub3 = strrep(RefVar(4,:),' ',''); 
                sub4 = strrep(RefVar(5,:),' ',''); 
                path = hh.(sub1).(sub2).(sub3).(sub4);
    end
    
    ReferenceVar(1:N,1) = path;
end

%% Generate influenced variable (target) within hh-struct as Nx1 vector
depth = numel(ChangeV(:,1));
switch depth 
    case 1
        path = hh.(ChangeV);
    case 2
        sub1 = strrep(ChangeV(1,:),' ','');
        sub2 = strrep(ChangeV(2,:),' ','');
        path = hh.(sub1).(sub2);
    case 3
        sub1 = strrep(ChangeV(1,:),' ','');
        sub2 = strrep(ChangeV(2,:),' ','');
        sub3 = strrep(ChangeV(3,:),' ','');
        path = hh.(sub1).(sub2).(sub3);
    case 4
        sub1 = strrep(ChangeV(1,:),' ','');
        sub2 = strrep(ChangeV(2,:),' ','');
        sub3 = strrep(ChangeV(3,:),' ','');
        sub4 = strrep(ChangeV(4,:),' ','');
        path = hh.(sub1).(sub2).(sub3).(sub4);
    otherwise
        error('ChangeVar with invalid depth. Must be 1-4 within hh-struct.')
end

% ISSUE: Change size of vectors! Make all Nx1 from the "beginning"...
try % allow for both Nx1 and 1xN vectors of target (override 1xN)
    target = cell2mat(path);
catch
    target = cell2mat(path);
end

if ~isequal(size(target),size(ReferenceVar))
    error('ReferenceVar and target (constructed according to ChangeVar) are not of equal size. Both must be Nx1.')
end
  
%% IT: load verb-noun combi and channel of effect

% ITv = Info: effect is 0-1 dummy; = Trust: effect is 1,2,3,4,5
% ITn indicates the institution (SFOE or utility)
EffectStrength = cell2mat(hh.IT.(ITv).(ITn)); 
% channel gives strength of perceived pressure
ChannelStrength = cell2mat(hh.NI.(Chan));

maxES = max(EffectStrength);
maxCS = max(ChannelStrength);

% Form indicator vectors to later define non-linear effect
IMaxES = (EffectStrength==maxES);
IStrongES = (EffectStrength>0.75*maxES) - IMaxES;
IMaxCS = (ChannelStrength==maxCS);
IStrongCS = (ChannelStrength>0.75*maxCS) - IMaxCS;

FullStrength = (IMaxES+IMaxCS==2);
PartlyFS = (IMaxES+IMaxCS==1);
Strong = (IStrongES+IStrongCS==2);
PartlySt = max(0,(IStrongES+IStrongCS==1) - PartlyFS);

NotWeak = FullStrength + PartlyFS + Strong + PartlySt;
if max(NotWeak)>1
    error('max(NotWeak)>1: Check indicator variables for EffectStrength and ChannelStrength.')
end
Weak = 1- NotWeak;

% Aggregate Strength
AggStrength = MaxEf(1)*FullStrength + MaxEf(2)*PartlyFS + ...
    MaxEf(3)*Strong + MaxEf(4)*PartlySt + MaxEf(5)*Weak ;

% Unrestricted change
urchange = max(Floor,min(Ceil,AggStrength .* (ReferenceVar - target)));
% Restrict change
switch Rel
    case 'eq' % two-sided adjustment
        change = urchange;
    case 'geq' % only values "too low" change
        change = max(0,urchange);
    case 'leq' % only values "too high" change
        change = min(0,urchange);
end

% set change back to zero if campaign only for specifc cluster  
if TargetClSN == 1
    change(clusters==2) =  0;
    change(clusters==3) =  0;
    change(clusters==4) =  0;
    change(clusters==5) =  0;
elseif TargetClSN == 2
    change(clusters==1) =  0;
    change(clusters==3) =  0;
    change(clusters==4) =  0;
    change(clusters==5) =  0;
elseif TargetClSN == 3
    change(clusters==1) =  0;
    change(clusters==2) =  0;
    change(clusters==4) =  0;
    change(clusters==5) =  0;    
elseif TargetClSN == 4
    change(clusters==1) =  0;
    change(clusters==2) =  0;
    change(clusters==3) =  0;
    change(clusters==5) =  0;                               
elseif TargetClSN == 5
    change(clusters==1) =  0;
    change(clusters==2) =  0;
    change(clusters==3) =  0;
    change(clusters==4) =  0;
elseif TargetClSN == 6 % campaign for cluster 1 & cluster 2
    change(clusters==3) =  0;
    change(clusters==4) =  0;
    change(clusters==5) =  0;
elseif TargetClSN == 7 % campaign for cluster 3 & cluster 4
    change(clusters==1) =  0;
    change(clusters==2) =  0;
    change(clusters==5) =  0;
end
                                                         
                        

% Summarize
UpdateVector = target + change;
% UpdateVector = max(0.3,min(UpdateVector,1));


%% Save and update

% Save in IDInst struct
IDInst.target = target;
IDInst.FullStrength = FullStrength;
IDInst.PartlyFS = PartlyFS;
IDInst.Strong = Strong;
IDInst.PartlySt = PartlySt;
IDInst.NotWeak = NotWeak;
IDInst.EffectStrength = EffectStrength;
IDInst.ChannelStrength = ChannelStrength;
IDInst.AggStrength = AggStrength;
IDInst.change = change;
IDInst.update = UpdateVector;

% Update hh-struct in cell format and save in Nx1 format (pot. overwrite)
updatecell = mat2cell(UpdateVector,hh.N,1); 
switch depth
    case 1
        hh.(ChangeV) = updatecell;
    case 2
        hh.(sub1).(sub2) = updatecell;
    case 3
        hh.(sub1).(sub2).(sub3) = updatecell;
    case 4 
        hh.(sub1).(sub2).(sub3).(sub4) = updatecell;
end

end