function Cl = ImpData2Cl_Nx2_bycl(Cl,ImpData,inputname,outputname,oul1,oul2,oul3)
%IMPDATA2CL_NX2_bycl Writes ImpData, which is reported by cl-specific
%   files, into Cl structure.
%%%%%%%%%
% Input:
% Cl structure, with required field: number 
% ImpData structure, with required fields: numdesc, numinj, numlit,
%   (inputname).predict/se.
% inputname char vector that contains (list of) input variable(s)
%   (ImpData.(inputname).predict/se has to exist).
% outlowerlevel determines outputname for inputname (equal length)
% oul1,oul2,oul3 gives Cl.(outupperlevel1).(...2).(...3).(outlowerlevel)...
%   if not required, set to 'none'.
%%%%%%%%%
% Output: 
% 4-dimensional matrix of form
%   Cl.[(oul1...3).](outputname).mean/se(desc,inj,lit,cl).

% indicate if any cluster reacts significantly different depending 
% on the levels of descriptive or injunctive norms or literacy.
for vars=1:numel(inputname(:,1))

    dimcase_bycl = zeros(Cl.number,1); 

    for cl=1:Cl.number

        % check how many dimensions relevant (different lengths of input vars)
        varname_cl=[strrep(inputname(vars,:),' ',''),num2str(cl)];
        length_varname = numel(ImpData.(varname_cl).predict);

        if length_varname==ImpData.numdesc * ImpData.numinj * ImpData.numlit
            dimcase_bycl(cl) = 1;
        end
        if length_varname==ImpData.numdesc * ImpData.numinj
            dimcase_bycl(cl) = 2;
        end
        if length_varname==ImpData.numdesc * ImpData.numlit
            dimcase_bycl(cl) = 3;
        end
        if length_varname==ImpData.numdesc
            dimcase_bycl(cl) = 4;
        end
        if length_varname==ImpData.numinj * ImpData.numlit
            dimcase_bycl(cl) = 5;
        end
        if length_varname==ImpData.numinj
            dimcase_bycl(cl) = 6;
        end
        if length_varname==ImpData.numlit
            dimcase_bycl(cl) = 7;
        end
        if length_varname==1
            dimcase_bycl(cl) = 8;
        end
        if dimcase_bycl(cl) == 0 % i.e., if dimcase_bycl not changed
            error('length_varname = %.0f is not a combination of numdesc, numinj, and numlit.')
        end
    end

    % set mean and SE of Cl.(outupperlevel).(outlowervars) at the required 
    % level of detail (i.e. as indicated above); output to matrix with 
    % dimensions (desc,inj,lit,cl)

    meancalc = zeros(ImpData.numdesc,ImpData.numinj,ImpData.numlit,Cl.number); 
    secalc = zeros(ImpData.numdesc,ImpData.numinj,ImpData.numlit,Cl.number); 

    for cl=1:Cl.number
        varname_cl=[strrep(inputname(vars,:),' ',''),num2str(cl)];
        switch dimcase_bycl(cl)
            case 1 % desc inj lit sig. diff
                for desc=1:ImpData.numdesc 
                    for inj=1:ImpData.numinj
                        for lit=1:ImpData.numlit
                            meancalc(desc,inj,lit,cl) = ...
                                ImpData.(varname_cl).predict( ...
                                (desc - 1) * (ImpData.numinj * ImpData.numlit) ...
                                + (inj - 1) * (ImpData.numlit) ...
                                + lit ...
                                );
                            secalc(desc,inj,lit,cl) = ...
                                ImpData.(varname_cl).se( ...
                                (desc - 1) * (ImpData.numinj * ImpData.numlit) ...
                                + (inj - 1) * (ImpData.numlit) ...
                                + lit ...
                                );
                        end
                    end
                end
            case 2 % desc inj sig. different, same for all lit
                for desc=1:ImpData.numdesc 
                    for inj=1:ImpData.numinj
                        meancalc(desc,inj,:,cl) = ...
                            ImpData.(varname_cl).predict( ...
                            (desc - 1) * (ImpData.numinj) ...
                            + inj ...
                            );
                        secalc(desc,inj,:,cl) = ...
                            ImpData.(varname_cl).se( ...
                            (desc - 1) * (ImpData.numinj) ...
                            + inj ...
                            );
                    end
                end
            case 3 % desc lit sig. different, same for all inj
                for desc=1:ImpData.numdesc 
                    for lit=1:ImpData.numlit
                        meancalc(desc,:,lit,cl) = ...
                            ImpData.(varname_cl).predict( ...
                            (desc - 1) * (ImpData.numlit) ...
                            + lit ...
                            );
                        secalc(desc,:,lit,cl) = ...
                            ImpData.(varname_cl).se( ...
                            (desc - 1) * (ImpData.numlit) ...
                            + lit ...
                            );
                    end
                end
            case 4 % desc sig. different, same for all inj lit
                for desc=1:ImpData.numdesc 
                    meancalc(desc,:,:,cl) = ...
                        ImpData.(varname_cl).predict( ...
                        desc ...
                        );
                    secalc(desc,:,:,cl) = ...
                        ImpData.(varname_cl).se( ...
                        desc ...
                        );
                end
            case 5 % inj lit sig. different, same for all desc
                for inj=1:ImpData.numinj
                    for lit=1:ImpData.numlit
                        meancalc(:,inj,lit,cl) = ...
                            ImpData.(varname_cl).predict( ...
                            (inj - 1) * (ImpData.numlit) ...
                            + lit ...
                            );
                        secalc(:,inj,lit,cl) = ...
                            ImpData.(varname_cl).se( ...
                            (inj - 1) * (ImpData.numlit) ...
                            + lit ...
                            );
                    end
                end
            case 6 % inj sig. different, same for all desc lit
                for inj=1:ImpData.numinj
                    meancalc(:,inj,:,cl) = ...
                        ImpData.(varname_cl).predict( ...
                        inj ...
                        );
                    secalc(:,inj,:,cl) = ...
                        ImpData.(varname_cl).se( ...
                        inj ...
                        );
                end
            case 7 % lit sig. different, same for all desc inj
                for lit=1:ImpData.numlit
                    meancalc(:,:,lit,cl) = ...
                        ImpData.(varname_cl).predict( ...
                        lit ...
                        );
                    secalc(:,:,lit,cl) = ...
                        ImpData.(varname_cl).se( ...
                        lit ...
                        );
                end
            case 8 % no sig. different, same for all desc inj lit
                meancalc(:,:,:,cl) = ...
                    ImpData.(varname_cl).predict( ...
                    1 ...
                    );
                secalc(:,:,:,cl) = ...
                    ImpData.(varname_cl).se( ...
                    1 ...
                    );
        end
    end

    % save output
    outname=strrep(outputname(vars,:),' ','');
    switch oul1
        case 'none'
            Cl.(outname).mean = meancalc; 
            Cl.(outname).se = secalc; 
        otherwise
            switch oul2
                case 'none'
                    Cl.(oul1).(outname).mean = meancalc; 
                    Cl.(oul1).(outname).se = secalc; 
                otherwise
                    switch oul3
                        case 'none'
                            Cl.(oul1).(oul2).(outname).mean = meancalc;
                            Cl.(oul1).(oul2).(outname).se = secalc;
                        otherwise
                            Cl.(oul1).(oul2).(oul3).(outname).mean = meancalc;
                            Cl.(oul1).(oul2).(oul3).(outname).se = secalc;
                    end
            end
    end       
end       
end

