function [hh, NW, report] = Initialization(hh,report,Input,ImpData,modes,assign_modes,ip,maxiter)
%INITIALIZATION Initialization of households
%%%%%%%%%
% Input
% Structures: hh, report, Input, ImpData, modes, assign_modes
% Parameters: ip, maxiter
%%%%%%%%%
% Returns/updates: hh, NW, report structures

% Define HHs by cluster
hh.N=Input.EA.N; % Set number of households by cluster equal to cluster size.
hh.ClNumber=Input.number;
hh.share=Input.EA.share;
%N=sum(hh.N); % Total number of households

% Assign household cluster
hh.cl{hh.ClNumber,1} = 0; 
for cl = 1:hh.ClNumber % cluster loop
    for h = 1:hh.N(cl) % household loop
        hh.cl{cl,1}(h,1) = cl;
    end
end

% Assign household category and category variables
hh.cat.cat{hh.ClNumber,1} = 0; % gives category of each household
hh.cat.number=Input.Cat.number;
hh.cat.share=Input.Cat.EA.share;
hh.cat.CondProb=Input.Cat.EA.CondProb;

hh.large = hh.cat.cat;
hh.owner = hh.cat.cat;
hh.rich	 = hh.cat.cat;

for cl = 1:hh.ClNumber % cluster loop
    hh.cat.cat{cl,1} = NaN(hh.N(cl),1);
    
    hh.large{cl,1} = zeros(hh.N(cl),1);
    hh.owner{cl,1} = hh.large{cl,1};
    hh.rich{cl,1}  = hh.large{cl,1};
    
    for h = 1:hh.N(cl) % household loop
        
        % Assign categories
        for cat = 1:hh.cat.number % category loop
            if rand < hh.cat.CondProb(cat,cl) && isnan(hh.cat.cat{cl,1}(h))
                hh.cat.cat{cl,1}(h) = cat;
            end
        end
        
        % Assign dummy variables according to category
        % Cat1-4: large households
        if hh.cat.cat{cl,1}(h)<5 
            hh.large{cl,1}(h) = 1;
        end
        % Cat1256: owner households
        if hh.cat.cat{cl,1}(h) == 1 || hh.cat.cat{cl,1}(h) == 2 || ...
                hh.cat.cat{cl,1}(h) == 5 || hh.cat.cat{cl,1}(h) == 6
            hh.owner{cl,1}(h) = 1;
        end	
        % odd Cat: rich households
        if mod(hh.cat.cat{cl,1}(h),2) == 1 
            hh.rich{cl,1}(h) = 1;
        end	
    end % close hh loop
end % close type loop


%% Assign HHs to cantons
switch Input.KtImport
    case 1 % assign on cl level
        for cl = 1:hh.ClNumber % cluster loop
            % Assign canton variables
            hh.canton.id{cl,1} = NaN(hh.N(cl),1);

            for h = 1:hh.N(cl) % household loop      
                % Assign cantons
                for kt=1:Input.KtNumber % canton loop         
                    if rand < Input.ClKtCondProb(kt,cl) && isnan(hh.canton.id{cl,1}(h))
                        hh.canton.id{cl,1}(h) = kt;                
                    end
                end 
                hh.canton.name{cl,1}(h,1) = Input.ClKtName{hh.canton.id{cl,1}(h,1)};
            end
        end

    case 2 % assign on cl and cat level
        for cl = 1:hh.ClNumber % cluster loop
            % Assign canton variables
            hh.canton.id{cl,1} = NaN(hh.N(cl),1);

            for h = 1:hh.N(cl) % household loop 
                cc = hh.cat.cat{cl,1}(h);
                % Assign cantons
                for kt=1:Input.KtNumber % canton loop         
                    if rand < Input.ClCatKtCondProb(cl,cc,kt) && isnan(hh.canton.id{cl,1}(h))
                        hh.canton.id{cl,1}(h) = kt;                
                    end
                end 
                hh.canton.name{cl,1}(h,1) = Input.ClKtName{hh.canton.id{cl,1}(h,1)};
            end
        end
        
end
hh.canton.CantonNumber = max(cell2mat(hh.canton.id));

%% Assign cantons to regions:
%   1. French and german speaking regions
%   2. Grossregionen

% French and german speaking regions:
% parameter with 1 if french speaking regions (FR, VD, VS, NE, GE) and
% 0 otherwise

for cl = 1:hh.ClNumber
    hh.canton.language_region{cl,1} = NaN(hh.N(cl),1);
    for h = 1:hh.N(cl)
        if hh.canton.id{cl,1}(h) == 6 || hh.canton.id{cl,1}(h) == 14 || ...
                hh.canton.id{cl,1}(h) == 15 || hh.canton.id{cl,1}(h) == 16 || ...
                hh.canton.id{cl,1}(h) == 17
                
                hh.canton.language_region{cl,1}(h) = 1;                
        else            
                hh.canton.language_region{cl,1}(h) = 0;
        end
    end
end

%% Assign norms and information (NI) variables on households

hh = NI_AssignHH(hh,Input,ImpData,assign_modes,ip);
report = NI_Reporting(hh,report,ip,maxiter);


%% Assign information and trust (IT) variables on households

switch modes.IT
    case 'active'
        disp('Information and trust module activated (modes.IT=active).')
        
        hh = IT_AssignHH(hh,Input,ip);
        report = IT_Reporting(hh,report,ip,maxiter);
            
    case 'inactive'
        disp('Information and trustmodule not activated (modes.IT=inactive).')
    
    otherwise
        warning('Information and trust module neither active nor inactive: modes.IT=%s.\n (Treated as inactive.)\n',modes.IT)
        modes.IT='inactive';
end


%% Assign electricity variables on households

% assign stock of EA, of large and small EAs, and of EEAs
switch modes.EA
    case 'active'
        disp('Electronic appliances module activated (modes.EA=active).')
        hh = EA_AssignHH(hh,Input,assign_modes,ip);
        report = EA_Reporting(hh,report,ip,maxiter);
        
    case 'inactive'
        disp('Electronic appliances module not activated (modes.EA=inactive).')
    
    otherwise
        warning('Electronic appliances module neither active nor inactive: modes.EA=%s. (Treated as inactive.)',...
            modes.EA)
        modes.EA = 'inactive';
end

% assign stock of EU, of large and small EAs, and of EEAs
switch modes.EU
    case 'active'
        disp('Electricity usage module activated (modes.EU=active).')
        hh = EU_AssignHH(hh,Input,ip);
        report = EU_Reporting(hh,report,ip,maxiter);
        
    case 'inactive'
        disp('Electricity usage module not activated (modes.EU=inactive).')
    
    otherwise
        warning('Electricity usage module neither active nor inactive: modes.EU=%s. (Treated as inactive.)',...
            modes.EU)
        modes.EU = 'inactive';
end


%% Create network structures

for nw = 1:numel(Input.NW.MeanSize)
    NWName = (strrep(Input.NW.NWNames(nw,:),' ','')); % set fieldname
    NW.(NWName) = NW_Creation(Input.NW.MeanSize(nw),...
                            Input.NW.BelongTwo(nw),...
                            Input.NW.ClCorr(nw),...
                            Input.NW.Cl6Corr(nw),...
                            Input.NW.Cl6RegionCorr(nw),... 
                            hh.N,NWName,...
                            Input.NW.Segregation,...
                            Input.NW.SegregationCriteria,hh...
                          );  
    switch Input.figures_initialization
        case 'active'  
            NW.(NWName) = NW_Plot(NW.(NWName),NWName);
    end
    NW.(NWName) = NW_Update(NW.(NWName),hh,modes);
    report.NW.(NWName) = [];
    report.NW.(NWName) = NW_Reporting(report.NW.(NWName),...
        NW.(NWName),ip,maxiter,modes);
end
toc


%% Check initialization
switch Input.figures_initialization
    case 'active' 
        for byc=1:2 % byc=1: histogram by category byc=2: by cluster
            forc='all'; % if byc=1: forc=x for cluster x, if byc=2: for category x

            % Check distribution of large/owner/rich by cluster/category
            field = char('large','owner','rich');
            for fld = 1:numel(field(:,1))
                fldnm = (strrep(field(fld,:),' ','')); %set fieldname
                datadesc = fldnm; 
                data =  hh.(fldnm);
                Histogram_byc(byc,forc,datadesc,data,hh)
            end

            % Check distribution of NI by cluster/category
            field = char('Desc','Inj','Lit');
            for fld = 1:numel(field(:,1))
                fldnm = (strrep(field(fld,:),' ','')); %set fieldname
                datadesc = ['NI.',fldnm]; 
                data =  hh.NI.(fldnm);
                Histogram_byc(byc,forc,datadesc,data,hh)
            end

            switch modes.EA
                case 'active'
                    % Check distribution of EA by cluster/category
                    Histogram_byc(byc,forc,'EA.stock',hh.EA.stock,hh)
                    Histogram_byc(byc,forc,'EA.large.stock',hh.EA.large.stock,hh)
                    Histogram_byc(byc,forc,'EA.large.share',hh.EA.large.share,hh)
                    Histogram_byc(byc,forc,'EA.large.EEA.share',hh.EA.large.EEA.share,hh)
                    Histogram_byc(byc,forc,'EA.large.EEA.stock',hh.EA.large.EEA.stock,hh)
            end

            switch modes.EU
                case 'active'
                    % Check distribution of EU by cluster/category
                    Histogram_byc(byc,forc,'EU.level',hh.EU.level,hh)
                    Histogram_byc(byc,forc,'EU.EffortLevel',hh.EU.EffortLevel,hh)
            end

        end

        switch modes.IT
            case 'active'
                % Check distribution of IT by cluster
                byc = 2;
                forc = 'all';
                from = hh.IT.from; % load sources of IT from hh struct
                field = char('Info','Trust');

                for f = 1:length(from(:,1))
                    source = strrep(from(f,:),' ','');
                    for fld = 1:numel(field(:,1))
                        fldnm = (strrep(field(fld,:),' ','')); %set fieldname
                        datadesc = ['IT.',fldnm,'.',source]; 
                        data =  hh.IT.(fldnm).(source);
                        Histogram_byc(byc,forc,datadesc,data,hh)
                    end
                end
        end
end % end of switch
close all

end


