function NW = NW_Creation(MeanSize,BelongTwo,ClCorr,Cl6Corr,Cl6RegionCorr,NByCl,NWName,Segregation,SetSegregationCriteria,hh)
%NW_Creation Creates network and assigns households
%%%%%%%%%
% Input
% MeanSize \in [1,N]: avg size of NW
% BelongTwo \in [0,1]: share of HH belonging to two NWs
% NByCl: Vector of household cluster sizes 
% ClCorr \in [0,1]: Correlation of network composition by Cluster
%  (0: random assignment, 1: all members of same Cl) 
% Cl6Cor: correlation of network composition by Cluster (with 6 clusters)
% Cl6RegionCorr: correlation region
% NByCl: number of HHs by Cluster
% NWName: NW Name
% Segregation: segregation active?
% SetSegregationCriteria: criteria for segregation
% hh: household strucutre
%%%%%%%%%
% Returns: NW structure
% NW.Set: MeanSize, BelongTwo
% NW.Number: number of NWs created
% NW.ID: cell array listing NW ID for each hh (incl. 2nd NW)
% NW.ID2: cell array indicating which hh associated to 2 NWs
% NW.Size: number of members for each NW
% NW.Members: list of hh IDs comprising each NW (members)
% NW.MemByCl: list of NW composition by cluster

NW.Set.MeanSize = MeanSize;
NW.Set.BelongTwo = BelongTwo;
NW.Set.ClCorr = ClCorr;
NW.Set.Cl6Corr = Cl6Corr;
NW.Set.Cl6RegionCorr = Cl6RegionCorr;

NumCl = numel(NByCl);
N = sum(NByCl);

% NByCl for 6 clusters
NByCl6      = zeros(6,1);
NByCl6      = NByCl;
NByCl6(5)   = ceil(NByCl(5)/2);
NByCl6(6)   = floor(NByCl(5)/2);
% set number of cluster to 6: divide cl5 in city and agglo&country: 50:50
    % Cl1: young city
    % Cl2: young agglo&country,
    % Cl3: middleold city, 
    % Cl4: middleold agglo&country
    % Cl5: old city
    % Cl6: old agglo&country
NumCl6      = numel(NByCl6); 
interval_nr = 3;   

if ~exist('ClCorr','var')
    % ClCorr does not exist
    warning('ClCorr was not assigned. Set to 0 (no correlation).')
    Cl6Corr = 0;
end


if MeanSize > N/2 % Create only one network that contains all HHs
    NW.Number = round(N/MeanSize);
    warning('MeanSize = %.0f (> N/2 = %.0f). \nAll households allocated to one network. BelongTwo treated as 0.',...
        MeanSize,N/2)
elseif MeanSize == 1 % Each hh has its own "network"
    NW.Number = N;
    warning('MeanSize = 1. Each hh has its own "network". Value of BelongTwo ignored.')
else
    NW.Number = round((1+BelongTwo)*N/MeanSize);
    fprintf('MeanSize = %.0f, BelongTwo = %.2f (percentage of houesholds belonging to two networks), NW.Number = %.0f (total number of networks being created), ClCorr = %.2f (Correlation of NWs by cluster).\n',...
        MeanSize,BelongTwo,NW.Number,Cl6Corr);
end

%% household setup

switch MeanSize
    case 1 % network size = 1 -> assign every household to own NW
        
        hhNWID(:,1) = 1:N;
        % nobody belongs to two networks
        hhNWID2 = zeros(N,1);
        
    otherwise % network size > 1 -> real NW structure
        
        switch Cl6Corr
            case 0 % random assignment
                % assign network 
                % (assign for each hh -> each hh belongs to one NW)
                % use fix() instead of round()
                hhNWID(:,1) = min(NW.Number, ...
                    1 + fix(rand(N,1) .* NW.Number)); % rand(N1,) determines length of hhNWID
                % determine who belongs to two networks
                hhNWID2(:,1) = (rand(N,1) < BelongTwo);
                % assign secondary network links 
                % Do not sort hhNWID to allow for meaningful interpretation 
                % of primary and secondary treatments (e.g., for 
                % information diffusion).
                hhNWID(:,2) = hhNWID2(:) ...
                    .* min(NW.Number, 1 + fix(rand(N,1) .* NW.Number));
                
            otherwise % positive correlation of Cl and NW
                
                % assign number of networks by cluster
                NW.NumberByCl = max(1,round(NW.Number.*(NByCl./N)));
                NW.NumberByCl6 = max(1,round(NW.Number.*(NByCl6./N)));
                
                if sum(NW.NumberByCl6)~=NW.Number
                    warning('NW.Number set to sum(NW.NumberByCl6)=%.0f (from %.0f)',...
                        sum(NW.NumberByCl6),NW.Number)
                    NW.Number = sum(NW.NumberByCl6);
                end
                
                
                % define if NWs are created without or with
                % segregation:  
                % 0 = no segregation
                % 1 = segregation by HH characteristics (e.g. norms, literacy, trust): segregation criteria must be integer between 1 and 5
                % 2 = segregation by language region
                % 3 = segregation by grossregion
                switch Segregation
                    case 0%---------------- NWs created without segregation -----------------------------
                                % assign number of networks by cluster - with 6 clusters
                                NW.NumberByCl6 = max(1,round(NW.Number.*(NByCl6./N)));
                                NW.Number = sum(NW.NumberByCl6);
                                % hh vectors of length N to ...
                                hhCl=zeros(N,1); % indicate cluster 
                                NWCl=hhCl; % number of networks to be created for each Cl
                                stock=hhCl; % "stock" of NWs already assigned "before" cl
                                stock_rand=zeros(N,1); % number of networks to be created for each Cl and interval - for random assignment 
                                NWCl_rand=zeros(N,1); % "stock" of NWs already assigned "before" cl and interval - for random assignment 


                                     %loop over the intervals to define which cluster could be in which NW 
                                for interval = 1:interval_nr
                                    for cl6=1:NumCl6
                                        hhCl(...
                                            (1+sum(NByCl6(1:cl6-1))) ... lowest hh ID of cl
                                            :sum(NByCl6(1:cl6))...highest hh ID of cl
                                            ,1) ...
                                            = cl6;
                                        %stock and NWCl for non-random assigment
                                        stock(hhCl==cl6)=sum(NW.NumberByCl6(1:cl6-1));
                                        NWCl(hhCl==cl6)=NW.NumberByCl6(cl6);

                                        % define intervals needed for random assignment of
                                        % hh to cl and nw; different for family, friends
                                        % and neighborhood
                                        switch NWName
                                            case 'Friends'
                                                switch cl6
                                                    case {1,3,5}
                                                        NW.Set.nwcl_intervals(cl6,interval) = sum(NW.NumberByCl6(cl6:cl6+1));
                                                        NW.Set.stock_intervals(cl6,interval) = sum(NW.NumberByCl6(1:cl6-1));
                                                    case {2,4,6}
                                                        NW.Set.nwcl_intervals(cl6,interval) = NW.Set.nwcl_intervals(cl6-1,interval);
                                                        NW.Set.stock_intervals(cl6,interval) = NW.Set.stock_intervals(cl6-1,interval);
                                                end
                                            case 'Neighborhood'
                                                switch cl6
                                                    case {1,3,5} 
                                                        NW.Set.nwcl_intervals(cl6,interval) = NW.NumberByCl6(interval+interval-1);
                                                        NW.Set.stock_intervals(cl6,interval) = sum(NW.NumberByCl6(1:((interval-1)*2)));
                                                    case {2,4,6} 
                                                        NW.Set.nwcl_intervals(cl6,interval) = NW.NumberByCl6(interval+interval);
                                                        NW.Set.stock_intervals(cl6,interval) = sum(NW.NumberByCl6(1:(interval+(interval-1))));
                                                end
                                            otherwise
                                                NW.Set.nwcl_intervals(cl6,interval) = NW.Number;
                                                NW.Set.stock_intervals(cl6,interval) = 0;
                                        end
                                        %stock and NWCl for random assigment
                                        stock_rand(hhCl==cl6)= NW.Set.stock_intervals(cl6,interval);
                                        NWCl_rand(hhCl==cl6) = NW.Set.nwcl_intervals(cl6,interval);
                                        stock_rand_interval(:,interval) = stock_rand; 
                                        NWCl_rand_interval(:,interval) = NWCl_rand; 
                                    end
                                end

                    case 1%---------------- NWs created with segregation by HH characteristics -----------------------------
                        % Segregation Criteria (e.g. norms, trust or literacy) can be defined dynamically:
                        
                        % call previously defined segregation criteria (defined in NW_Parameters):
                        % segregation criteria must be integers between 1 and 5: 
                        % e.g. trust in SFOE, fam or desc norms 

                        SegCriteria = SetSegregationCriteria;
                        depth = numel(SegCriteria(:,1));
                        switch depth 
                            case 1
                                path = hh.(SegCriteria);
                            case 2
                                sub1 = strrep(SegCriteria(1,:),' ','');
                                sub2 = strrep(SegCriteria(2,:),' ','');
                                path = hh.(sub1).(sub2);
                            case 3
                                sub1 = strrep(SegCriteria(1,:),' ','');
                                sub2 = strrep(SegCriteria(2,:),' ','');
                                sub3 = strrep(SegCriteria(3,:),' ','');
                                path = hh.(sub1).(sub2).(sub3);
                            case 4
                                sub1 = strrep(SegCriteria(1,:),' ','');
                                sub2 = strrep(SegCriteria(2,:),' ','');
                                sub3 = strrep(SegCriteria(3,:),' ','');
                                sub4 = strrep(SegCriteria(4,:),' ','');
                                path = hh.(sub1).(sub2).(sub3).(sub4);
                            otherwise
                                error('SegCriteria with invalid depth. Must be 1-4 within hh-struct.')
                        end                                                                                     
                        
                        for cl = 1:5
                            CriteriaForSegregation{cl,1} = path{cl,1};
                        end
 
%                         % Literacy categories (1-5) for segregation                        
%                         for cl = 1:5
%                             hh.NI.LitCategory{cl,1}=zeros(hh.NByCl(cl),1);
%                             for h = 1:hh.NByCl(cl)
%                                 if hh.NI.Lit{cl,1}(h) <= 2
%                                     hh.NI.LitCategory{cl,1}(h) = 1;
%                                 elseif hh.NI.Lit{cl,1}(h) > 2 && hh.NI.Lit{cl,1}(h) <= 5
%                                     hh.NI.LitCategory{cl,1}(h) = 2;
%                                 elseif hh.NI.Lit{cl,1}(h) > 5 && hh.NI.Lit{cl,1}(h) <= 7
%                                     hh.NI.LitCategory{cl,1}(h) = 3;   
%                                 elseif hh.NI.Lit{cl,1}(h) > 7 && hh.NI.Lit{cl,1}(h) <= 9
%                                     hh.NI.LitCategory{cl,1}(h) = 4;
%                                 elseif hh.NI.Lit{cl,1}(h) > 9 
%                                     hh.NI.LitCategory{cl,1}(h) = 5;
%                                 end                                
%                             end
%                         end
%                         for cl = 1:5
%                             CriteriaForSegregation{cl,1} = hh.NI.LitCategory{cl,1};
%                         end                        
                        
%                         % Inj Norms categories (1-5) for segregation 
%                         for cl = 1:5
%                             CriteriaForSegregation{cl,1} = round(hh.NI.Inj{cl,1});
%                         end
                        
                        
                        % segregation criteria: from 5 to 6 clusters
                        for cl6 = 1:6 % loop over 6 clusters
                            CriteriaForSegregationCl6{cl6,1} = zeros(NByCl6(cl6),1);
                            if cl6<5
                                CriteriaForSegregationCl6{cl6,1} = CriteriaForSegregation{cl6,1};
                            elseif cl6 ==5
                                CriteriaForSegregationCl6{cl6,1}(1:(ceil(NByCl(5)/2))) = CriteriaForSegregation{5,1}(1:(ceil(NByCl(5)/2)));
                            elseif cl6 ==6
                                CriteriaForSegregationCl6{cl6,1}(1:(floor(NByCl(5)/2))) = CriteriaForSegregation{5,1}(((ceil(NByCl(5)/2))+1):NByCl(5));
                            end
                        end

                        % Number of HHs by Segregation Criteria 
                        for cl6 = 1:6 % loop over 6 clusters
                            for seg = 1:5
                                NumberOfHHsBySeg{seg,cl6} = sum(CriteriaForSegregationCl6{cl6,1} == seg);
                            end
                        end                        
                        NumberOfHHsBySegCriteria = reshape(NumberOfHHsBySeg,[],1);
                        %NumberOfHHsBySegCriteria2 = cell2mat(NumberOfHHsBySegCriteria);
                        
                        % Number of NWs by Cl6 and Seg
                        NW.NumberByCl6 = zeros(30,1);
                        for clseg = 1:30 % type loop
                            NW.NumberByCl6(clseg) = max(1,round(NW.Number.*(NumberOfHHsBySegCriteria{clseg}./N)));
                        end                  
                        NW.Number = sum(NW.NumberByCl6);

                        hhClSeg=zeros(N,1);
                        stock=zeros(N,1);
                        NWCl=zeros(N,1);

                        for cl6=1:NumCl6
                            seg_criteria = CriteriaForSegregationCl6{cl6,1};
                            % allocate HHs to Cl6 and Seg
                            hhClSeg(...
                                (1+sum(NByCl6(1:cl6-1))) ... lowest hh ID of cl
                                    :sum(NByCl6(1:cl6))...highest hh ID of cl
                                    ,1) ...
                                    = cl6 * 5 - (5 - seg_criteria);
                        end
                        
                        for clseg=1:30                          
                            %stock and NWCl for non-random assigment
                            stock(hhClSeg==clseg)=sum(NW.NumberByCl6(1:clseg-1));
                            NWCl(hhClSeg==clseg)=NW.NumberByCl6(clseg);
                        end
                        % stock and nwcl by clseg
                        for clseg=1:30  
                            avg_stock_clseg(clseg,1) = mean(stock(hhClSeg == clseg));
                            avg_NWCl_clseg(clseg,1) = mean(NWCl(hhClSeg == clseg));
                        end
                        
                                                                   
                        % define intervals needed for random assignment of
                        % hh to cl, seg and nw; different for family, friends
                        % and neighborhood

                        switch NWName
                            case 'Friends'
                                % reshape stock and nwcl for NW and seg specific assignment 
                                avg_stock_clseg_reshape = reshape(avg_stock_clseg,[],6);
                                avg_NWCl_clseg_reshape = reshape(avg_NWCl_clseg,[],6);

                                avg_stock_clseg_ordered(1:5,1:2) = avg_stock_clseg_reshape(1:5,1:2);
                                avg_stock_clseg_ordered(6:10,1:2) = avg_stock_clseg_reshape(1:5,1:2);
                                avg_stock_clseg_ordered(11:15,1:2) = avg_stock_clseg_reshape(1:5,3:4);
                                avg_stock_clseg_ordered(16:20,1:2) = avg_stock_clseg_reshape(1:5,3:4);
                                avg_stock_clseg_ordered(21:25,1:2) = avg_stock_clseg_reshape(1:5,5:6);
                                avg_stock_clseg_ordered(26:30,1:2) = avg_stock_clseg_reshape(1:5,5:6);
                                avg_NWCl_clseg_ordered(1:5,1:2) = avg_NWCl_clseg_reshape(1:5,1:2);
                                avg_NWCl_clseg_ordered(6:10,1:2) = avg_NWCl_clseg_reshape(1:5,1:2);
                                avg_NWCl_clseg_ordered(11:15,1:2) = avg_NWCl_clseg_reshape(1:5,3:4);
                                avg_NWCl_clseg_ordered(16:20,1:2) = avg_NWCl_clseg_reshape(1:5,3:4);
                                avg_NWCl_clseg_ordered(21:25,1:2) = avg_NWCl_clseg_reshape(1:5,5:6);
                                avg_NWCl_clseg_ordered(26:30,1:2) = avg_NWCl_clseg_reshape(1:5,5:6);

                            case 'Neighborhood'
                                % reshape stock and nwcl for NW and seg specific assignment                        
                                avg_stock_clseg_reshape = reshape(avg_stock_clseg,[],3);
                                avg_NWCl_clseg_reshape = reshape(avg_NWCl_clseg,[],3);

                                avg_stock_clseg_ordered(1:10,1:3) = avg_stock_clseg_reshape(1:10,1:3);
                                avg_stock_clseg_ordered(11:20,1:3) = avg_stock_clseg_reshape(1:10,1:3);
                                avg_stock_clseg_ordered(21:30,1:3) = avg_stock_clseg_reshape(1:10,1:3);
                                avg_NWCl_clseg_ordered(1:10,1:3) = avg_NWCl_clseg_reshape(1:10,1:3);
                                avg_NWCl_clseg_ordered(11:20,1:3) = avg_NWCl_clseg_reshape(1:10,1:3);
                                avg_NWCl_clseg_ordered(21:30,1:3) = avg_NWCl_clseg_reshape(1:10,1:3);


                            otherwise % Family
                                % reshape stock and nwcl for NW and seg specific assignment 
                                avg_stock_clseg_reshape = reshape(avg_stock_clseg,[],6);
                                avg_NWCl_clseg_reshape = reshape(avg_NWCl_clseg,[],6);

                                avg_stock_clseg_ordered(1:5,1:6) = avg_stock_clseg_reshape(1:5,1:6);
                                avg_stock_clseg_ordered(6:10,1:6) = avg_stock_clseg_reshape(1:5,1:6);
                                avg_stock_clseg_ordered(11:15,1:6) = avg_stock_clseg_reshape(1:5,1:6);
                                avg_stock_clseg_ordered(16:20,1:6) = avg_stock_clseg_reshape(1:5,1:6);
                                avg_stock_clseg_ordered(21:25,1:6) = avg_stock_clseg_reshape(1:5,1:6);
                                avg_stock_clseg_ordered(26:30,1:6) = avg_stock_clseg_reshape(1:5,1:6);
                                avg_NWCl_clseg_ordered(1:5,1:6) = avg_NWCl_clseg_reshape(1:5,1:6);
                                avg_NWCl_clseg_ordered(6:10,1:6) = avg_NWCl_clseg_reshape(1:5,1:6);
                                avg_NWCl_clseg_ordered(11:15,1:6) = avg_NWCl_clseg_reshape(1:5,1:6);
                                avg_NWCl_clseg_ordered(16:20,1:6) = avg_NWCl_clseg_reshape(1:5,1:6);
                                avg_NWCl_clseg_ordered(21:25,1:6) = avg_NWCl_clseg_reshape(1:5,1:6);
                                avg_NWCl_clseg_ordered(26:30,1:6) = avg_NWCl_clseg_reshape(1:5,1:6);               
                        end
                        for clseg = 1:30
                            %stock and NWCl for random assigment
                            NW.Set.stock_intervals_seg(clseg,:) = avg_stock_clseg_ordered(clseg,:);
                            NW.Set.nwcl_intervals_seg(clseg,:) = avg_NWCl_clseg_ordered(clseg,:);
                        end
                        
                        stock_rand=zeros(N,size(NW.Set.stock_intervals_seg,2));
                        NWCl_rand=zeros(N,size(NW.Set.stock_intervals_seg,2));
                        for n = 1:N
                            stock_rand(n,:)= NW.Set.stock_intervals_seg(hhClSeg(n),:);
                            NWCl_rand(n,:) = NW.Set.nwcl_intervals_seg(hhClSeg(n),:);
                        end
                        stock_rand_interval = stock_rand; 
                        NWCl_rand_interval= NWCl_rand; 
                        
            
                        
                case 2%---------------- NWs created with segregation by language region -----------------------------
                        % language_region:
                        % 1 = german speaking
                        % 2 = french speaking
                        for cl = 1:5
                            CriteriaForSegregation{cl,1} = hh.canton.language_region{cl,1} + 1;
                        end                        
                        
                        % segregation criteria: from 5 to 6 clusters
                        for cl6 = 1:6 % loop over 6 clusters
                            CriteriaForSegregationCl6{cl6,1} = zeros(NByCl6(cl6),1);
                            if cl6<5
                                CriteriaForSegregationCl6{cl6,1} = CriteriaForSegregation{cl6,1};
                            elseif cl6 ==5
                                CriteriaForSegregationCl6{cl6,1}(1:(ceil(NByCl(5)/2))) = CriteriaForSegregation{5,1}(1:(ceil(NByCl(5)/2)));
                            elseif cl6 ==6
                                CriteriaForSegregationCl6{cl6,1}(1:(floor(NByCl(5)/2))) = CriteriaForSegregation{5,1}(((ceil(NByCl(5)/2))+1):NByCl(5));
                            end
                        end

                        % Number of HHs by Segregation Criteria 
                        for cl6 = 1:6 % loop over 6 clusters
                            for seg = 1:2
                                NumberOfHHsBySeg{seg,cl6} = sum(CriteriaForSegregationCl6{cl6,1} == seg);
                            end
                        end                        
                        NumberOfHHsBySegCriteria = reshape(NumberOfHHsBySeg,[],1);
                        
                        % Number of NWs by Cl6 and Seg
                        %NW.NumberByCl6 = zeros(12,1);
                        for clseg = 1:12 % type loop
                            NW.NumberByCl6(clseg) = max(1,round(NW.Number.*(NumberOfHHsBySegCriteria{clseg}./N)));
                        end                  
                        NW.Number = sum(NW.NumberByCl6);
                        
                        hhClSeg=zeros(N,1);
                        stock=zeros(N,1);
                        NWCl=zeros(N,1);

                        for cl6=1:NumCl6
                            seg_criteria = CriteriaForSegregationCl6{cl6,1};
                            % allocate HHs to Cl6 and Seg
                            hhClSeg(...
                                (1+sum(NByCl6(1:cl6-1))) ... lowest hh ID of cl
                                    :sum(NByCl6(1:cl6))...highest hh ID of cl
                                    ,1) ...
                                    = cl6 * 2 - (2 - seg_criteria);                           
                        end
                        
                        for clseg=1:12                          
                            %stock and NWCl for non-random assigment
                            stock(hhClSeg==clseg)=sum(NW.NumberByCl6(1:clseg-1));
                            NWCl(hhClSeg==clseg)=NW.NumberByCl6(clseg);
                        end
                        % stock and nwcl by clseg
                        for clseg=1:12  
                            avg_stock_clseg(clseg,1) = mean(stock(hhClSeg == clseg));
                            avg_NWCl_clseg(clseg,1) = mean(NWCl(hhClSeg == clseg));
                        end
                        
                                                                   
                        % define intervals needed for random assignment of
                        % hh to cl, seg and nw; different for family, friends
                        % and neighborhood

                        switch NWName
                            case 'Friends'
                                % reshape stock and nwcl for NW and seg specific assignment 
                                avg_stock_clseg_reshape = reshape(avg_stock_clseg,[],6);
                                avg_NWCl_clseg_reshape = reshape(avg_NWCl_clseg,[],6);

                                avg_stock_clseg_ordered(1:2,1:2) = avg_stock_clseg_reshape(1:2,1:2);
                                avg_stock_clseg_ordered(3:4,1:2) = avg_stock_clseg_reshape(1:2,1:2);                           
                                avg_stock_clseg_ordered(5:6,1:2) = avg_stock_clseg_reshape(1:2,3:4);
                                avg_stock_clseg_ordered(7:8,1:2) = avg_stock_clseg_reshape(1:2,3:4);
                                avg_stock_clseg_ordered(9:10,1:2) = avg_stock_clseg_reshape(1:2,5:6);
                                avg_stock_clseg_ordered(11:12,1:2) = avg_stock_clseg_reshape(1:2,5:6);                                
                                avg_NWCl_clseg_ordered(1:2,1:2) = avg_NWCl_clseg_reshape(1:2,1:2);
                                avg_NWCl_clseg_ordered(3:4,1:2) = avg_NWCl_clseg_reshape(1:2,1:2);                           
                                avg_NWCl_clseg_ordered(5:6,1:2) = avg_NWCl_clseg_reshape(1:2,3:4);
                                avg_NWCl_clseg_ordered(7:8,1:2) = avg_NWCl_clseg_reshape(1:2,3:4);
                                avg_NWCl_clseg_ordered(9:10,1:2) = avg_NWCl_clseg_reshape(1:2,5:6);
                                avg_NWCl_clseg_ordered(11:12,1:2) = avg_NWCl_clseg_reshape(1:2,5:6);

                            case 'Neighborhood'
                                % reshape stock and nwcl for NW and seg specific assignment                        
                                avg_stock_clseg_reshape = reshape(avg_stock_clseg,[],3);
                                avg_NWCl_clseg_reshape = reshape(avg_NWCl_clseg,[],3);

                                avg_stock_clseg_ordered(1:4,1:3) = avg_stock_clseg_reshape(1:4,1:3);
                                avg_stock_clseg_ordered(5:8,1:3) = avg_stock_clseg_reshape(1:4,1:3);
                                avg_stock_clseg_ordered(9:12,1:3) = avg_stock_clseg_reshape(1:4,1:3);                                
                                avg_NWCl_clseg_ordered(1:4,1:3) = avg_NWCl_clseg_reshape(1:4,1:3);
                                avg_NWCl_clseg_ordered(5:8,1:3) = avg_NWCl_clseg_reshape(1:4,1:3);
                                avg_NWCl_clseg_ordered(9:12,1:3) = avg_NWCl_clseg_reshape(1:4,1:3);


                            otherwise % Family
                                % reshape stock and nwcl for NW and seg specific assignment 
                                avg_stock_clseg_reshape = reshape(avg_stock_clseg,[],6);
                                avg_NWCl_clseg_reshape = reshape(avg_NWCl_clseg,[],6);

                                avg_stock_clseg_ordered(1:2,1:6) = avg_stock_clseg_reshape(1:2,1:6);
                                avg_stock_clseg_ordered(3:4,1:6) = avg_stock_clseg_reshape(1:2,1:6);
                                avg_stock_clseg_ordered(5:6,1:6) = avg_stock_clseg_reshape(1:2,1:6);
                                avg_stock_clseg_ordered(7:8,1:6) = avg_stock_clseg_reshape(1:2,1:6);
                                avg_stock_clseg_ordered(9:10,1:6) = avg_stock_clseg_reshape(1:2,1:6);
                                avg_stock_clseg_ordered(11:12,1:6) = avg_stock_clseg_reshape(1:2,1:6); 
                                avg_NWCl_clseg_ordered(1:2,1:6) = avg_NWCl_clseg_reshape(1:2,1:6);
                                avg_NWCl_clseg_ordered(3:4,1:6) = avg_NWCl_clseg_reshape(1:2,1:6);
                                avg_NWCl_clseg_ordered(5:6,1:6) = avg_NWCl_clseg_reshape(1:2,1:6);
                                avg_NWCl_clseg_ordered(7:8,1:6) = avg_NWCl_clseg_reshape(1:2,1:6);
                                avg_NWCl_clseg_ordered(9:10,1:6) = avg_NWCl_clseg_reshape(1:2,1:6);
                                avg_NWCl_clseg_ordered(11:12,1:6) = avg_NWCl_clseg_reshape(1:2,1:6);   
                        end
                        for clseg = 1:12
                            %stock and NWCl for random assigment
                            NW.Set.stock_intervals_seg(clseg,:) = avg_stock_clseg_ordered(clseg,:);
                            NW.Set.nwcl_intervals_seg(clseg,:) = avg_NWCl_clseg_ordered(clseg,:);
                        end
                        
                        stock_rand=zeros(N,size(NW.Set.stock_intervals_seg,2));
                        NWCl_rand=zeros(N,size(NW.Set.stock_intervals_seg,2));
                        for n = 1:N
                            stock_rand(n,:)= NW.Set.stock_intervals_seg(hhClSeg(n),:);
                            NWCl_rand(n,:) = NW.Set.nwcl_intervals_seg(hhClSeg(n),:);
                        end
                        stock_rand_interval = stock_rand; 
                        NWCl_rand_interval= NWCl_rand; 
                        
                        
                case 3%---------------- NWs created with segregation by grossregion -----------------------------
                    
                    
                    
                end%---------------- end of segregation -----------------------------
                
                
                stock_random=zeros(N,1);
                NWCl_random=zeros(N,1);
                
                % randomly assign one interval for each hh for random assignment
                % dependend on cl and nw
                for loop = 1:N
                     r = randi([1,size(stock_rand_interval,2)],1,1);
                     stock_random(loop) =  stock_rand_interval(loop,r);
                     NWCl_random(loop)  =  NWCl_rand_interval(loop,r);
                end
                NW.Set.stock = stock;
                NW.Set.NWCl = NWCl;                                                     
                NW.Set.stock_random = stock_random;
                NW.Set.NWCl_random = NWCl_random;
                
                % assign network:
                % Family: could be random over all clusters
                % Friends: own or same age clusters
                % Neighborhood: own or same location clusters               
                
                % choose hhs for random assignment
                RandomAss=(rand(N,2)>=Cl6Corr); 
                % (assign for each hh -> each hh belongs to one NW)
                
                 hhNWID = RandomAss(:,1).* ...% random assignment
                        (1 + stock_random + fix(rand(N,1) .* NWCl_random))...
                    + (1 - RandomAss(:,1)).*...% non-random assignment
                        (1 + stock + fix(rand(N,1) .* NWCl));

                % assign secondary network links  
                 % determine who belongs to two networks
                hhNWID2(:,1) = (rand(N,1) < BelongTwo);
                              
                hhNWID(:,2) = hhNWID2 ...
                    .* RandomAss(:,2).* ...% random assignment
                        (1 + stock_random + fix(rand(N,1) .* NWCl_random))...
                    + (1 - RandomAss(:,2)).*...% non-random assignment
                        (1 + stock + fix(rand(N,1) .* NWCl));
                                    
                
                % identify (potential) cases of 1st = 2nd network
                warning_2nd_norand(:,1) = (hhNWID(:,1)==hhNWID(:,2) ...
                    & RandomAss(:,2)==0);

                if min(NW.NumberByCl6)>1 % at least two networks per cluster
                    % increase 2nd values by 1
                    hhNWID(:,2) = hhNWID(:,2) + warning_2nd_norand(:);
                    % (if this concerns the "last" network of the respective 
                    % cluster, replace it with its "first" network)
                    lastNW = (hhNWID(:,2) > NWCl+stock & RandomAss(:,2) == 0);
                    hhNWID(lastNW,2) = hhNWID(lastNW,2)-NWCl(lastNW);      
                else
                    warning('min(NW.NumberByCl) = %.0f. Double assignments to NWs removed. \nBelongTwo only applies to RandomAss = 1 households.',...
                        min(NW.NumberByCl6))
                    hhNWID(warning_2nd_norand,2) = NaN;
                end
        
        end
                 
        % replace zeros of hh belonging to only one NW with NaN
        hhNWID(hhNWID2==0,2) = NaN;
        % identify (potential) cases of 1st = 2nd network
        warning_2nd(:,1) = (hhNWID(:,1)==hhNWID(:,2));
        % and increase these values by 1
        %hhNWID(:,2) = hhNWID(:,2) + warning_2nd(:);
        % (if this concerns the "last" network, replace it with 1)       
        %hhNWID(hhNWID(:) > NW.Number) = 1;
        if warning_2nd(:)==1  
            % set it to NaN
            hhNWID(:,2) = NaN;
        else
            hhNWID(:,2) =  hhNWID(:,2);
        end
                          
end

% NWID with 5 clusters
NW.ID = mat2cell(hhNWID,NByCl,numel(hhNWID(1,:))); 
NW.ID2 = mat2cell(hhNWID2,NByCl,numel(hhNWID2(1,:)));

% NWID with 6 clusters
NW.ID_cl6= mat2cell(hhNWID,NByCl6,numel(hhNWID(1,:))); 
NW.ID2_cl6 = mat2cell(hhNWID2,NByCl6,numel(hhNWID2(1,:)));
        


%% NW setup

% count members of each network
[~,~,idx] = unique(hhNWID(~isnan(hhNWID)));
NW.Size  = accumarray(idx(:),1);
NW.ActMeanSize = mean(NW.Size);

% check length of NW.Size 
CheckNrNW = numel(NW.Size) - NW.Number;
if CheckNrNW ~= 0
    error('Number of NWs used (numel(NW.Size) = %.0f) not equal to number of NWs available (NW.Number = %.0f).Check assignment.',...
        numel(NW.Size),NW.Number)
end

% list members and correct the ID of 2nd NW members (i.e., members>N)
NW.Members = NaN(NW.Number,max(NW.Size)); % allow for maximum size of NW
for n=1:NW.Number
    members = find(hhNWID==n);
    members(members>N) = members(members>N) - N; 
    NW.Members(n,1:numel(members)) = members ;
end
    
% identify membership by cluster
NW.MemByCl = NW.Members;
for cl6=1:NumCl6
        NW.MemByCl(...
            NW.Members >  sum(NByCl6(1:cl6-1)) ...
            & ...
            NW.Members <= sum(NByCl6(1:cl6)) ...
            ) ...
        = cl6;
end

% check if assignment adds up to cluster size
[~,~,idx] = unique(NW.MemByCl(~isnan(NW.MemByCl)));
CheckClSize_NW  = accumarray(idx(:),1);

CheckClSize_hh = zeros(NumCl6);
for cl6=1:NumCl6
    CheckClSize_hh(cl6) = NByCl6(cl6) + sum(NW.ID2_cl6 {cl6,1}(:)); % account for ID2
end

Zerocheck = CheckClSize_NW - CheckClSize_hh;

if sum(Zerocheck)>0
    error('Error in CreateNW. Clustersizes of hh and NW mismatch. Check network assignment procedure.')
end
%]

end

